From 4967240dbdb1653db21b71849c79896a00ea8f3b Mon Sep 17 00:00:00 2001
From: Mark Dilger <mark.dilger@enterprisedb.com>
Date: Tue, 3 Aug 2021 09:43:14 -0700
Subject: [PATCH v5 04/12] Adding role pg_manage_autovacuum_settings

This new role can SET and ALTER SYSTEM SET any GUC variable which
controls autovacuum behavior or resource usage.
---
 doc/src/sgml/user-manag.sgml                  |    9 +-
 src/backend/utils/misc/guc.c                  |   30 +-
 src/include/catalog/pg_authid.dat             |    5 +
 src/include/utils/guc.h                       |    1 +
 .../expected/guc_priv_autovacuum_admin.out    | 2473 +++++++++++++++++
 src/test/regress/parallel_schedule            |    2 +-
 .../regress/sql/guc_priv_autovacuum_admin.sql | 1423 ++++++++++
 7 files changed, 3927 insertions(+), 16 deletions(-)
 create mode 100644 src/test/regress/expected/guc_priv_autovacuum_admin.out
 create mode 100644 src/test/regress/sql/guc_priv_autovacuum_admin.sql

diff --git a/doc/src/sgml/user-manag.sgml b/doc/src/sgml/user-manag.sgml
index fac3312d6c..dca943465e 100644
--- a/doc/src/sgml/user-manag.sgml
+++ b/doc/src/sgml/user-manag.sgml
@@ -589,6 +589,10 @@ DROP ROLE doomed_role;
        <entry>pg_manage_vacuum_settings</entry>
        <entry>Allow changing settings which control vacuum behavior.</entry>
       </row>
+      <row>
+       <entry>pg_manage_autovacuum_settings</entry>
+       <entry>Allow changing settings which control autovacuum behavior.</entry>
+      </row>
      </tbody>
     </tgroup>
    </table>
@@ -633,8 +637,9 @@ DROP ROLE doomed_role;
   </para>
 
   <para>
-  The <literal>pg_manage_host_resource_settings</literal> and
-  <literal>pg_manage_vacuum_settings</literal> roles are intended to allow
+  The <literal>pg_manage_host_resource_settings</literal>,
+  <literal>pg_manage_vacuum_settings</literal> and
+  <literal>pg_manage_autovacuum_settings</literal> roles are intended to allow
   administrators to have trusted, but non-superuser, roles to configure the
   server.
   </para>
diff --git a/src/backend/utils/misc/guc.c b/src/backend/utils/misc/guc.c
index f7f2893746..4d515bc9f9 100644
--- a/src/backend/utils/misc/guc.c
+++ b/src/backend/utils/misc/guc.c
@@ -1629,7 +1629,7 @@ static struct config_bool ConfigureNamesBool[] =
 		{"autovacuum", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Starts the autovacuum subprocess."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_start_daemon,
 		true,
@@ -2652,7 +2652,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_vacuum_cost_limit", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Vacuum cost amount available before napping, for autovacuum."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_vac_cost_limit,
 		-1, -1, 10000,
@@ -3438,7 +3438,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_naptime", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Time to sleep between autovacuum runs."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_AUTOVACUUM_SETTINGS,
 			GUC_UNIT_S
 		},
 		&autovacuum_naptime,
@@ -3449,7 +3449,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_vacuum_threshold", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Minimum number of tuple updates or deletes prior to vacuum."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_vac_thresh,
 		50, 0, INT_MAX,
@@ -3459,7 +3459,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_vacuum_insert_threshold", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Minimum number of tuple inserts prior to vacuum, or -1 to disable insert vacuums."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_vac_ins_thresh,
 		1000, -1, INT_MAX,
@@ -3469,7 +3469,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_analyze_threshold", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Minimum number of tuple inserts, updates, or deletes prior to analyze."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_anl_thresh,
 		50, 0, INT_MAX,
@@ -3480,7 +3480,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_freeze_max_age", PGC_POSTMASTER, AUTOVACUUM,
 			gettext_noop("Age at which to autovacuum a table to prevent transaction ID wraparound."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_freeze_max_age,
 
@@ -3496,7 +3496,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_multixact_freeze_max_age", PGC_POSTMASTER, AUTOVACUUM,
 			gettext_noop("Multixact age at which to autovacuum a table to prevent multixact wraparound."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_multixact_freeze_max_age,
 		400000000, 10000, 2000000000,
@@ -3507,7 +3507,7 @@ static struct config_int ConfigureNamesInt[] =
 		{"autovacuum_max_workers", PGC_POSTMASTER, AUTOVACUUM,
 			gettext_noop("Sets the maximum number of simultaneously running autovacuum worker processes."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_max_workers,
 		3, 1, MAX_BACKENDS,
@@ -3998,7 +3998,7 @@ static struct config_real ConfigureNamesReal[] =
 		{"autovacuum_vacuum_cost_delay", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Vacuum cost delay in milliseconds, for autovacuum."),
 			NULL,
-			GUC_SUPERUSER_ONLY,
+			GUC_MANAGE_AUTOVACUUM_SETTINGS,
 			GUC_UNIT_MS
 		},
 		&autovacuum_vac_cost_delay,
@@ -4010,7 +4010,7 @@ static struct config_real ConfigureNamesReal[] =
 		{"autovacuum_vacuum_scale_factor", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Number of tuple updates or deletes prior to vacuum as a fraction of reltuples."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_vac_scale,
 		0.2, 0.0, 100.0,
@@ -4021,7 +4021,7 @@ static struct config_real ConfigureNamesReal[] =
 		{"autovacuum_vacuum_insert_scale_factor", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Number of tuple inserts prior to vacuum as a fraction of reltuples."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_vac_ins_scale,
 		0.2, 0.0, 100.0,
@@ -4032,7 +4032,7 @@ static struct config_real ConfigureNamesReal[] =
 		{"autovacuum_analyze_scale_factor", PGC_SIGHUP, AUTOVACUUM,
 			gettext_noop("Number of tuple inserts, updates, or deletes prior to analyze as a fraction of reltuples."),
 			NULL,
-			GUC_SUPERUSER_ONLY
+			GUC_MANAGE_AUTOVACUUM_SETTINGS
 		},
 		&autovacuum_anl_scale,
 		0.1, 0.0, 100.0,
@@ -7613,6 +7613,10 @@ role_has_privileges(Oid roleid, int privileges)
 		! has_privs_of_role(roleid, ROLE_PG_MANAGE_VACUUM_SETTINGS))
 		return false;
 
+	if ((privileges & GUC_MANAGE_AUTOVACUUM_SETTINGS) &&
+		! has_privs_of_role(roleid, ROLE_PG_MANAGE_AUTOVACUUM_SETTINGS))
+		return false;
+
 	return true;
 }
 
diff --git a/src/include/catalog/pg_authid.dat b/src/include/catalog/pg_authid.dat
index cef9b7f015..588b0954d8 100644
--- a/src/include/catalog/pg_authid.dat
+++ b/src/include/catalog/pg_authid.dat
@@ -89,5 +89,10 @@
   rolcreaterole => 'f', rolcreatedb => 'f', rolcanlogin => 'f',
   rolreplication => 'f', rolbypassrls => 't', rolconnlimit => '-1',
   rolpassword => '_null_', rolvaliduntil => '_null_' },
+{ oid => '9281', oid_symbol => 'ROLE_PG_MANAGE_AUTOVACUUM_SETTINGS',
+  rolname => 'pg_manage_autovacuum_settings', rolsuper => 'f', rolinherit => 't',
+  rolcreaterole => 'f', rolcreatedb => 'f', rolcanlogin => 'f',
+  rolreplication => 'f', rolbypassrls => 't', rolconnlimit => '-1',
+  rolpassword => '_null_', rolvaliduntil => '_null_' },
 
 ]
diff --git a/src/include/utils/guc.h b/src/include/utils/guc.h
index 1cae7d2935..5627b53895 100644
--- a/src/include/utils/guc.h
+++ b/src/include/utils/guc.h
@@ -203,6 +203,7 @@ typedef enum
  */
 #define GUC_MANAGE_HOST_RESOURCE_SETTINGS	0x0001
 #define GUC_MANAGE_VACUUM_SETTINGS			0x0002
+#define GUC_MANAGE_AUTOVACUUM_SETTINGS		0x0004
 
 /*
  * bit values in "flags" of a GUC variable
diff --git a/src/test/regress/expected/guc_priv_autovacuum_admin.out b/src/test/regress/expected/guc_priv_autovacuum_admin.out
new file mode 100644
index 0000000000..995fefd9c9
--- /dev/null
+++ b/src/test/regress/expected/guc_priv_autovacuum_admin.out
@@ -0,0 +1,2473 @@
+-- Non-superuser with privileges to configure autovacuum processes
+CREATE ROLE autovacuum_admin NOSUPERUSER;
+GRANT pg_manage_autovacuum_settings TO autovacuum_admin;
+-- Perform all operations as user 'autovacuum_admin' --
+SET SESSION AUTHORIZATION autovacuum_admin;
+-- PGC_BACKEND / DEVELOPER_OPTIONS
+SET ignore_system_indexes = OFF;  -- fail, cannot be set after connection start
+ERROR:  parameter "ignore_system_indexes" cannot be set after connection start
+RESET ignore_system_indexes;  -- fail, cannot be set after connection start
+ERROR:  parameter "ignore_system_indexes" cannot be set after connection start
+ALTER SYSTEM SET ignore_system_indexes = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_system_indexes"
+ALTER SYSTEM RESET ignore_system_indexes;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_system_indexes"
+SET post_auth_delay = 50;  -- fail, cannot be set after connection start
+ERROR:  parameter "post_auth_delay" cannot be set after connection start
+RESET post_auth_delay;  -- fail, cannot be set after connection start
+ERROR:  parameter "post_auth_delay" cannot be set after connection start
+ALTER SYSTEM SET post_auth_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "post_auth_delay"
+ALTER SYSTEM RESET post_auth_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "post_auth_delay"
+-- PGC_INTERNAL / PRESET_OPTIONS
+SET block_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "block_size" cannot be changed
+RESET block_size;  -- fail, cannot be changed
+ERROR:  parameter "block_size" cannot be changed
+ALTER SYSTEM SET block_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "block_size" cannot be changed
+ALTER SYSTEM RESET block_size;  -- fail, cannot be changed
+ERROR:  parameter "block_size" cannot be changed
+SET data_checksums = OFF;  -- fail, cannot be changed
+ERROR:  parameter "data_checksums" cannot be changed
+RESET data_checksums;  -- fail, cannot be changed
+ERROR:  parameter "data_checksums" cannot be changed
+ALTER SYSTEM SET data_checksums = OFF;  -- fail, cannot be changed
+ERROR:  parameter "data_checksums" cannot be changed
+ALTER SYSTEM RESET data_checksums;  -- fail, cannot be changed
+ERROR:  parameter "data_checksums" cannot be changed
+SET data_directory_mode = 50;  -- fail, cannot be changed
+ERROR:  parameter "data_directory_mode" cannot be changed
+RESET data_directory_mode;  -- fail, cannot be changed
+ERROR:  parameter "data_directory_mode" cannot be changed
+ALTER SYSTEM SET data_directory_mode = 50;  -- fail, cannot be changed
+ERROR:  parameter "data_directory_mode" cannot be changed
+ALTER SYSTEM RESET data_directory_mode;  -- fail, cannot be changed
+ERROR:  parameter "data_directory_mode" cannot be changed
+SET debug_assertions = OFF;  -- fail, cannot be changed
+ERROR:  parameter "debug_assertions" cannot be changed
+RESET debug_assertions;  -- fail, cannot be changed
+ERROR:  parameter "debug_assertions" cannot be changed
+ALTER SYSTEM SET debug_assertions = OFF;  -- fail, cannot be changed
+ERROR:  parameter "debug_assertions" cannot be changed
+ALTER SYSTEM RESET debug_assertions;  -- fail, cannot be changed
+ERROR:  parameter "debug_assertions" cannot be changed
+SET in_hot_standby = OFF;  -- fail, cannot be changed
+ERROR:  parameter "in_hot_standby" cannot be changed
+RESET in_hot_standby;  -- fail, cannot be changed
+ERROR:  parameter "in_hot_standby" cannot be changed
+ALTER SYSTEM SET in_hot_standby = OFF;  -- fail, cannot be changed
+ERROR:  parameter "in_hot_standby" cannot be changed
+ALTER SYSTEM RESET in_hot_standby;  -- fail, cannot be changed
+ERROR:  parameter "in_hot_standby" cannot be changed
+SET integer_datetimes = OFF;  -- fail, cannot be changed
+ERROR:  parameter "integer_datetimes" cannot be changed
+RESET integer_datetimes;  -- fail, cannot be changed
+ERROR:  parameter "integer_datetimes" cannot be changed
+ALTER SYSTEM SET integer_datetimes = OFF;  -- fail, cannot be changed
+ERROR:  parameter "integer_datetimes" cannot be changed
+ALTER SYSTEM RESET integer_datetimes;  -- fail, cannot be changed
+ERROR:  parameter "integer_datetimes" cannot be changed
+SET lc_collate = 'en_US.UTF-8';  -- fail, cannot be changed
+ERROR:  parameter "lc_collate" cannot be changed
+RESET lc_collate;  -- fail, cannot be changed
+ERROR:  parameter "lc_collate" cannot be changed
+ALTER SYSTEM SET lc_collate = 'en_US.UTF-8';  -- fail, cannot be changed
+ERROR:  parameter "lc_collate" cannot be changed
+ALTER SYSTEM RESET lc_collate;  -- fail, cannot be changed
+ERROR:  parameter "lc_collate" cannot be changed
+SET lc_ctype = 'en_US.UTF-8';  -- fail, cannot be changed
+ERROR:  parameter "lc_ctype" cannot be changed
+RESET lc_ctype;  -- fail, cannot be changed
+ERROR:  parameter "lc_ctype" cannot be changed
+ALTER SYSTEM SET lc_ctype = 'en_US.UTF-8';  -- fail, cannot be changed
+ERROR:  parameter "lc_ctype" cannot be changed
+ALTER SYSTEM RESET lc_ctype;  -- fail, cannot be changed
+ERROR:  parameter "lc_ctype" cannot be changed
+SET max_function_args = 50;  -- fail, cannot be changed
+ERROR:  parameter "max_function_args" cannot be changed
+RESET max_function_args;  -- fail, cannot be changed
+ERROR:  parameter "max_function_args" cannot be changed
+ALTER SYSTEM SET max_function_args = 50;  -- fail, cannot be changed
+ERROR:  parameter "max_function_args" cannot be changed
+ALTER SYSTEM RESET max_function_args;  -- fail, cannot be changed
+ERROR:  parameter "max_function_args" cannot be changed
+SET max_identifier_length = 50;  -- fail, cannot be changed
+ERROR:  parameter "max_identifier_length" cannot be changed
+RESET max_identifier_length;  -- fail, cannot be changed
+ERROR:  parameter "max_identifier_length" cannot be changed
+ALTER SYSTEM SET max_identifier_length = 50;  -- fail, cannot be changed
+ERROR:  parameter "max_identifier_length" cannot be changed
+ALTER SYSTEM RESET max_identifier_length;  -- fail, cannot be changed
+ERROR:  parameter "max_identifier_length" cannot be changed
+SET max_index_keys = 50;  -- fail, cannot be changed
+ERROR:  parameter "max_index_keys" cannot be changed
+RESET max_index_keys;  -- fail, cannot be changed
+ERROR:  parameter "max_index_keys" cannot be changed
+ALTER SYSTEM SET max_index_keys = 50;  -- fail, cannot be changed
+ERROR:  parameter "max_index_keys" cannot be changed
+ALTER SYSTEM RESET max_index_keys;  -- fail, cannot be changed
+ERROR:  parameter "max_index_keys" cannot be changed
+SET segment_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "segment_size" cannot be changed
+RESET segment_size;  -- fail, cannot be changed
+ERROR:  parameter "segment_size" cannot be changed
+ALTER SYSTEM SET segment_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "segment_size" cannot be changed
+ALTER SYSTEM RESET segment_size;  -- fail, cannot be changed
+ERROR:  parameter "segment_size" cannot be changed
+SET server_encoding = 'UTF8';  -- fail, cannot be changed
+ERROR:  parameter "server_encoding" cannot be changed
+RESET server_encoding;  -- fail, cannot be changed
+ERROR:  parameter "server_encoding" cannot be changed
+ALTER SYSTEM SET server_encoding = 'UTF8';  -- fail, cannot be changed
+ERROR:  parameter "server_encoding" cannot be changed
+ALTER SYSTEM RESET server_encoding;  -- fail, cannot be changed
+ERROR:  parameter "server_encoding" cannot be changed
+SET server_version = '9.1';  -- fail, cannot be changed
+ERROR:  parameter "server_version" cannot be changed
+RESET server_version;  -- fail, cannot be changed
+ERROR:  parameter "server_version" cannot be changed
+ALTER SYSTEM SET server_version = '9.1';  -- fail, cannot be changed
+ERROR:  parameter "server_version" cannot be changed
+ALTER SYSTEM RESET server_version;  -- fail, cannot be changed
+ERROR:  parameter "server_version" cannot be changed
+SET server_version_num = 50;  -- fail, cannot be changed
+ERROR:  parameter "server_version_num" cannot be changed
+RESET server_version_num;  -- fail, cannot be changed
+ERROR:  parameter "server_version_num" cannot be changed
+ALTER SYSTEM SET server_version_num = 50;  -- fail, cannot be changed
+ERROR:  parameter "server_version_num" cannot be changed
+ALTER SYSTEM RESET server_version_num;  -- fail, cannot be changed
+ERROR:  parameter "server_version_num" cannot be changed
+SET ssl_library = 'OpenSSL';  -- fail, cannot be changed
+ERROR:  parameter "ssl_library" cannot be changed
+RESET ssl_library;  -- fail, cannot be changed
+ERROR:  parameter "ssl_library" cannot be changed
+ALTER SYSTEM SET ssl_library = 'OpenSSL';  -- fail, cannot be changed
+ERROR:  parameter "ssl_library" cannot be changed
+ALTER SYSTEM RESET ssl_library;  -- fail, cannot be changed
+ERROR:  parameter "ssl_library" cannot be changed
+SET wal_block_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "wal_block_size" cannot be changed
+RESET wal_block_size;  -- fail, cannot be changed
+ERROR:  parameter "wal_block_size" cannot be changed
+ALTER SYSTEM SET wal_block_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "wal_block_size" cannot be changed
+ALTER SYSTEM RESET wal_block_size;  -- fail, cannot be changed
+ERROR:  parameter "wal_block_size" cannot be changed
+SET wal_segment_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "wal_segment_size" cannot be changed
+RESET wal_segment_size;  -- fail, cannot be changed
+ERROR:  parameter "wal_segment_size" cannot be changed
+ALTER SYSTEM SET wal_segment_size = 50;  -- fail, cannot be changed
+ERROR:  parameter "wal_segment_size" cannot be changed
+ALTER SYSTEM RESET wal_segment_size;  -- fail, cannot be changed
+ERROR:  parameter "wal_segment_size" cannot be changed
+-- PGC_INTERNAL / UNGROUPED
+SET is_superuser = OFF;  -- fail, cannot be changed
+ERROR:  parameter "is_superuser" cannot be changed
+RESET is_superuser;  -- fail, cannot be changed
+ERROR:  parameter "is_superuser" cannot be changed
+ALTER SYSTEM SET is_superuser = OFF;  -- fail, cannot be changed
+ERROR:  parameter "is_superuser" cannot be changed
+ALTER SYSTEM RESET is_superuser;  -- fail, cannot be changed
+ERROR:  parameter "is_superuser" cannot be changed
+-- PGC_POSTMASTER / AUTOVACUUM
+SET autovacuum_freeze_max_age = 1000050000;  -- fail, requires restart
+ERROR:  parameter "autovacuum_freeze_max_age" cannot be changed without restarting the server
+RESET autovacuum_freeze_max_age;  -- fail, requires restart
+ERROR:  parameter "autovacuum_freeze_max_age" cannot be changed without restarting the server
+ALTER SYSTEM SET autovacuum_freeze_max_age = 1000050000;  -- ok
+ALTER SYSTEM RESET autovacuum_freeze_max_age;  -- ok
+SET autovacuum_max_workers = 50;  -- fail, requires restart
+ERROR:  parameter "autovacuum_max_workers" cannot be changed without restarting the server
+RESET autovacuum_max_workers;  -- fail, requires restart
+ERROR:  parameter "autovacuum_max_workers" cannot be changed without restarting the server
+ALTER SYSTEM SET autovacuum_max_workers = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_max_workers;  -- ok
+SET autovacuum_multixact_freeze_max_age = 1000005000;  -- fail, requires restart
+ERROR:  parameter "autovacuum_multixact_freeze_max_age" cannot be changed without restarting the server
+RESET autovacuum_multixact_freeze_max_age;  -- fail, requires restart
+ERROR:  parameter "autovacuum_multixact_freeze_max_age" cannot be changed without restarting the server
+ALTER SYSTEM SET autovacuum_multixact_freeze_max_age = 1000005000;  -- ok
+ALTER SYSTEM RESET autovacuum_multixact_freeze_max_age;  -- ok
+-- PGC_POSTMASTER / CLIENT_CONN_PRELOAD
+SET jit_provider = 'llvmjit';  -- fail, requires restart
+ERROR:  parameter "jit_provider" cannot be changed without restarting the server
+RESET jit_provider;  -- fail, requires restart
+ERROR:  parameter "jit_provider" cannot be changed without restarting the server
+ALTER SYSTEM SET jit_provider = 'llvmjit';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_provider"
+ALTER SYSTEM RESET jit_provider;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_provider"
+SET shared_preload_libraries = 'iconv, pcre';  -- fail, requires restart
+ERROR:  parameter "shared_preload_libraries" cannot be changed without restarting the server
+RESET shared_preload_libraries;  -- fail, requires restart
+ERROR:  parameter "shared_preload_libraries" cannot be changed without restarting the server
+ALTER SYSTEM SET shared_preload_libraries = 'iconv, pcre';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_preload_libraries"
+ALTER SYSTEM RESET shared_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_preload_libraries"
+-- PGC_POSTMASTER / CONN_AUTH_SETTINGS
+SET bonjour = OFF;  -- fail, requires restart
+ERROR:  parameter "bonjour" cannot be changed without restarting the server
+RESET bonjour;  -- fail, requires restart
+ERROR:  parameter "bonjour" cannot be changed without restarting the server
+ALTER SYSTEM SET bonjour = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour"
+ALTER SYSTEM RESET bonjour;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour"
+SET bonjour_name = 'BonneNuit';  -- fail, requires restart
+ERROR:  parameter "bonjour_name" cannot be changed without restarting the server
+RESET bonjour_name;  -- fail, requires restart
+ERROR:  parameter "bonjour_name" cannot be changed without restarting the server
+ALTER SYSTEM SET bonjour_name = 'BonneNuit';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour_name"
+ALTER SYSTEM RESET bonjour_name;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bonjour_name"
+SET listen_addresses = 'localhost';  -- fail, requires restart
+ERROR:  parameter "listen_addresses" cannot be changed without restarting the server
+RESET listen_addresses;  -- fail, requires restart
+ERROR:  parameter "listen_addresses" cannot be changed without restarting the server
+ALTER SYSTEM SET listen_addresses = 'localhost';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "listen_addresses"
+ALTER SYSTEM RESET listen_addresses;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "listen_addresses"
+SET max_connections = 50;  -- fail, requires restart
+ERROR:  parameter "max_connections" cannot be changed without restarting the server
+RESET max_connections;  -- fail, requires restart
+ERROR:  parameter "max_connections" cannot be changed without restarting the server
+ALTER SYSTEM SET max_connections = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_connections"
+ALTER SYSTEM RESET max_connections;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_connections"
+SET port = 50;  -- fail, requires restart
+ERROR:  parameter "port" cannot be changed without restarting the server
+RESET port;  -- fail, requires restart
+ERROR:  parameter "port" cannot be changed without restarting the server
+ALTER SYSTEM SET port = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "port"
+ALTER SYSTEM RESET port;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "port"
+SET superuser_reserved_connections = 50;  -- fail, requires restart
+ERROR:  parameter "superuser_reserved_connections" cannot be changed without restarting the server
+RESET superuser_reserved_connections;  -- fail, requires restart
+ERROR:  parameter "superuser_reserved_connections" cannot be changed without restarting the server
+ALTER SYSTEM SET superuser_reserved_connections = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "superuser_reserved_connections"
+ALTER SYSTEM RESET superuser_reserved_connections;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "superuser_reserved_connections"
+SET unix_socket_directories = '/tmp';  -- fail, requires restart
+ERROR:  parameter "unix_socket_directories" cannot be changed without restarting the server
+RESET unix_socket_directories;  -- fail, requires restart
+ERROR:  parameter "unix_socket_directories" cannot be changed without restarting the server
+ALTER SYSTEM SET unix_socket_directories = '/tmp';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_directories"
+ALTER SYSTEM RESET unix_socket_directories;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_directories"
+SET unix_socket_group = 'tenant';  -- fail, requires restart
+ERROR:  parameter "unix_socket_group" cannot be changed without restarting the server
+RESET unix_socket_group;  -- fail, requires restart
+ERROR:  parameter "unix_socket_group" cannot be changed without restarting the server
+ALTER SYSTEM SET unix_socket_group = 'tenant';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_group"
+ALTER SYSTEM RESET unix_socket_group;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_group"
+SET unix_socket_permissions = 50;  -- fail, requires restart
+ERROR:  parameter "unix_socket_permissions" cannot be changed without restarting the server
+RESET unix_socket_permissions;  -- fail, requires restart
+ERROR:  parameter "unix_socket_permissions" cannot be changed without restarting the server
+ALTER SYSTEM SET unix_socket_permissions = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_permissions"
+ALTER SYSTEM RESET unix_socket_permissions;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "unix_socket_permissions"
+-- PGC_POSTMASTER / DEVELOPER_OPTIONS
+SET ignore_invalid_pages = OFF;  -- fail, requires restart
+ERROR:  parameter "ignore_invalid_pages" cannot be changed without restarting the server
+RESET ignore_invalid_pages;  -- fail, requires restart
+ERROR:  parameter "ignore_invalid_pages" cannot be changed without restarting the server
+ALTER SYSTEM SET ignore_invalid_pages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_invalid_pages"
+ALTER SYSTEM RESET ignore_invalid_pages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_invalid_pages"
+-- PGC_POSTMASTER / ERROR_HANDLING_OPTIONS
+SET data_sync_retry = OFF;  -- fail, requires restart
+ERROR:  parameter "data_sync_retry" cannot be changed without restarting the server
+RESET data_sync_retry;  -- fail, requires restart
+ERROR:  parameter "data_sync_retry" cannot be changed without restarting the server
+ALTER SYSTEM SET data_sync_retry = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "data_sync_retry"
+ALTER SYSTEM RESET data_sync_retry;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "data_sync_retry"
+-- PGC_POSTMASTER / FILE_LOCATIONS
+SET config_file = '/usr/local/data/postgresql.conf';  -- fail, requires restart
+ERROR:  parameter "config_file" cannot be changed without restarting the server
+RESET config_file;  -- fail, requires restart
+ERROR:  parameter "config_file" cannot be changed without restarting the server
+ALTER SYSTEM SET config_file = '/usr/local/data/postgresql.conf';  -- fail, cannot be changed
+ERROR:  parameter "config_file" cannot be changed
+ALTER SYSTEM RESET config_file;  -- fail, cannot be changed
+ERROR:  parameter "config_file" cannot be changed
+SET data_directory = '/usr/local/data';  -- fail, requires restart
+ERROR:  parameter "data_directory" cannot be changed without restarting the server
+RESET data_directory;  -- fail, requires restart
+ERROR:  parameter "data_directory" cannot be changed without restarting the server
+ALTER SYSTEM SET data_directory = '/usr/local/data';  -- fail, cannot be changed
+ERROR:  parameter "data_directory" cannot be changed
+ALTER SYSTEM RESET data_directory;  -- fail, cannot be changed
+ERROR:  parameter "data_directory" cannot be changed
+SET external_pid_file = '/var/postgres/master.pid';  -- fail, requires restart
+ERROR:  parameter "external_pid_file" cannot be changed without restarting the server
+RESET external_pid_file;  -- fail, requires restart
+ERROR:  parameter "external_pid_file" cannot be changed without restarting the server
+ALTER SYSTEM SET external_pid_file = '/var/postgres/master.pid';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "external_pid_file"
+ALTER SYSTEM RESET external_pid_file;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "external_pid_file"
+-- PGC_POSTMASTER / LOCK_MANAGEMENT
+SET max_locks_per_transaction = 50;  -- fail, requires restart
+ERROR:  parameter "max_locks_per_transaction" cannot be changed without restarting the server
+RESET max_locks_per_transaction;  -- fail, requires restart
+ERROR:  parameter "max_locks_per_transaction" cannot be changed without restarting the server
+ALTER SYSTEM SET max_locks_per_transaction = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_locks_per_transaction"
+ALTER SYSTEM RESET max_locks_per_transaction;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_locks_per_transaction"
+SET max_pred_locks_per_transaction = 50;  -- fail, requires restart
+ERROR:  parameter "max_pred_locks_per_transaction" cannot be changed without restarting the server
+RESET max_pred_locks_per_transaction;  -- fail, requires restart
+ERROR:  parameter "max_pred_locks_per_transaction" cannot be changed without restarting the server
+ALTER SYSTEM SET max_pred_locks_per_transaction = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_transaction"
+ALTER SYSTEM RESET max_pred_locks_per_transaction;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_transaction"
+-- PGC_POSTMASTER / LOGGING_WHERE
+SET event_source = 'PostgreSQL';  -- fail, requires restart
+ERROR:  parameter "event_source" cannot be changed without restarting the server
+RESET event_source;  -- fail, requires restart
+ERROR:  parameter "event_source" cannot be changed without restarting the server
+ALTER SYSTEM SET event_source = 'PostgreSQL';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "event_source"
+ALTER SYSTEM RESET event_source;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "event_source"
+SET logging_collector = OFF;  -- fail, requires restart
+ERROR:  parameter "logging_collector" cannot be changed without restarting the server
+RESET logging_collector;  -- fail, requires restart
+ERROR:  parameter "logging_collector" cannot be changed without restarting the server
+ALTER SYSTEM SET logging_collector = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logging_collector"
+ALTER SYSTEM RESET logging_collector;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logging_collector"
+-- PGC_POSTMASTER / PROCESS_TITLE
+SET cluster_name = 'BonCluster';  -- fail, requires restart
+ERROR:  parameter "cluster_name" cannot be changed without restarting the server
+RESET cluster_name;  -- fail, requires restart
+ERROR:  parameter "cluster_name" cannot be changed without restarting the server
+ALTER SYSTEM SET cluster_name = 'BonCluster';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cluster_name"
+ALTER SYSTEM RESET cluster_name;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cluster_name"
+-- PGC_POSTMASTER / REPLICATION_SENDING
+SET max_replication_slots = 50;  -- fail, requires restart
+ERROR:  parameter "max_replication_slots" cannot be changed without restarting the server
+RESET max_replication_slots;  -- fail, requires restart
+ERROR:  parameter "max_replication_slots" cannot be changed without restarting the server
+ALTER SYSTEM SET max_replication_slots = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_replication_slots"
+ALTER SYSTEM RESET max_replication_slots;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_replication_slots"
+SET max_wal_senders = 50;  -- fail, requires restart
+ERROR:  parameter "max_wal_senders" cannot be changed without restarting the server
+RESET max_wal_senders;  -- fail, requires restart
+ERROR:  parameter "max_wal_senders" cannot be changed without restarting the server
+ALTER SYSTEM SET max_wal_senders = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_wal_senders"
+ALTER SYSTEM RESET max_wal_senders;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_wal_senders"
+SET track_commit_timestamp = OFF;  -- fail, requires restart
+ERROR:  parameter "track_commit_timestamp" cannot be changed without restarting the server
+RESET track_commit_timestamp;  -- fail, requires restart
+ERROR:  parameter "track_commit_timestamp" cannot be changed without restarting the server
+ALTER SYSTEM SET track_commit_timestamp = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_commit_timestamp"
+ALTER SYSTEM RESET track_commit_timestamp;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_commit_timestamp"
+-- PGC_POSTMASTER / REPLICATION_STANDBY
+SET hot_standby = OFF;  -- fail, requires restart
+ERROR:  parameter "hot_standby" cannot be changed without restarting the server
+RESET hot_standby;  -- fail, requires restart
+ERROR:  parameter "hot_standby" cannot be changed without restarting the server
+ALTER SYSTEM SET hot_standby = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hot_standby"
+ALTER SYSTEM RESET hot_standby;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hot_standby"
+-- PGC_POSTMASTER / REPLICATION_SUBSCRIBERS
+SET max_logical_replication_workers = 50;  -- fail, requires restart
+ERROR:  parameter "max_logical_replication_workers" cannot be changed without restarting the server
+RESET max_logical_replication_workers;  -- fail, requires restart
+ERROR:  parameter "max_logical_replication_workers" cannot be changed without restarting the server
+ALTER SYSTEM SET max_logical_replication_workers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_logical_replication_workers"
+ALTER SYSTEM RESET max_logical_replication_workers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_logical_replication_workers"
+-- PGC_POSTMASTER / RESOURCES_ASYNCHRONOUS
+SET max_worker_processes = 50;  -- fail, requires restart
+ERROR:  parameter "max_worker_processes" cannot be changed without restarting the server
+RESET max_worker_processes;  -- fail, requires restart
+ERROR:  parameter "max_worker_processes" cannot be changed without restarting the server
+ALTER SYSTEM SET max_worker_processes = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_worker_processes"
+ALTER SYSTEM RESET max_worker_processes;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_worker_processes"
+SET old_snapshot_threshold = 50;  -- fail, requires restart
+ERROR:  parameter "old_snapshot_threshold" cannot be changed without restarting the server
+RESET old_snapshot_threshold;  -- fail, requires restart
+ERROR:  parameter "old_snapshot_threshold" cannot be changed without restarting the server
+ALTER SYSTEM SET old_snapshot_threshold = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "old_snapshot_threshold"
+ALTER SYSTEM RESET old_snapshot_threshold;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "old_snapshot_threshold"
+-- PGC_POSTMASTER / RESOURCES_KERNEL
+SET max_files_per_process = 1073741855;  -- fail, requires restart
+ERROR:  parameter "max_files_per_process" cannot be changed without restarting the server
+RESET max_files_per_process;  -- fail, requires restart
+ERROR:  parameter "max_files_per_process" cannot be changed without restarting the server
+ALTER SYSTEM SET max_files_per_process = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_files_per_process"
+ALTER SYSTEM RESET max_files_per_process;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_files_per_process"
+-- PGC_POSTMASTER / RESOURCES_MEM
+SET dynamic_shared_memory_type = 'posix';  -- fail, requires restart
+ERROR:  parameter "dynamic_shared_memory_type" cannot be changed without restarting the server
+RESET dynamic_shared_memory_type;  -- fail, requires restart
+ERROR:  parameter "dynamic_shared_memory_type" cannot be changed without restarting the server
+ALTER SYSTEM SET dynamic_shared_memory_type = 'posix';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_shared_memory_type"
+ALTER SYSTEM RESET dynamic_shared_memory_type;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_shared_memory_type"
+SET huge_pages = 'try';  -- fail, requires restart
+ERROR:  parameter "huge_pages" cannot be changed without restarting the server
+RESET huge_pages;  -- fail, requires restart
+ERROR:  parameter "huge_pages" cannot be changed without restarting the server
+ALTER SYSTEM SET huge_pages = 'try';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "huge_pages"
+ALTER SYSTEM RESET huge_pages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "huge_pages"
+SET max_prepared_transactions = 50;  -- fail, requires restart
+ERROR:  parameter "max_prepared_transactions" cannot be changed without restarting the server
+RESET max_prepared_transactions;  -- fail, requires restart
+ERROR:  parameter "max_prepared_transactions" cannot be changed without restarting the server
+ALTER SYSTEM SET max_prepared_transactions = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_prepared_transactions"
+ALTER SYSTEM RESET max_prepared_transactions;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_prepared_transactions"
+SET min_dynamic_shared_memory = 50;  -- fail, requires restart
+ERROR:  parameter "min_dynamic_shared_memory" cannot be changed without restarting the server
+RESET min_dynamic_shared_memory;  -- fail, requires restart
+ERROR:  parameter "min_dynamic_shared_memory" cannot be changed without restarting the server
+ALTER SYSTEM SET min_dynamic_shared_memory = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_dynamic_shared_memory"
+ALTER SYSTEM RESET min_dynamic_shared_memory;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_dynamic_shared_memory"
+SET shared_buffers = 50;  -- fail, requires restart
+ERROR:  parameter "shared_buffers" cannot be changed without restarting the server
+RESET shared_buffers;  -- fail, requires restart
+ERROR:  parameter "shared_buffers" cannot be changed without restarting the server
+ALTER SYSTEM SET shared_buffers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_buffers"
+ALTER SYSTEM RESET shared_buffers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_buffers"
+SET shared_memory_type = 'mmap';  -- fail, requires restart
+ERROR:  parameter "shared_memory_type" cannot be changed without restarting the server
+RESET shared_memory_type;  -- fail, requires restart
+ERROR:  parameter "shared_memory_type" cannot be changed without restarting the server
+ALTER SYSTEM SET shared_memory_type = 'mmap';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_memory_type"
+ALTER SYSTEM RESET shared_memory_type;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "shared_memory_type"
+-- PGC_POSTMASTER / STATS_COLLECTOR
+SET track_activity_query_size = 524338;  -- fail, requires restart
+ERROR:  parameter "track_activity_query_size" cannot be changed without restarting the server
+RESET track_activity_query_size;  -- fail, requires restart
+ERROR:  parameter "track_activity_query_size" cannot be changed without restarting the server
+ALTER SYSTEM SET track_activity_query_size = 524338;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activity_query_size"
+ALTER SYSTEM RESET track_activity_query_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activity_query_size"
+-- PGC_POSTMASTER / WAL_ARCHIVING
+SET archive_mode = 'off';  -- fail, requires restart
+ERROR:  parameter "archive_mode" cannot be changed without restarting the server
+RESET archive_mode;  -- fail, requires restart
+ERROR:  parameter "archive_mode" cannot be changed without restarting the server
+ALTER SYSTEM SET archive_mode = 'off';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_mode"
+ALTER SYSTEM RESET archive_mode;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_mode"
+-- PGC_POSTMASTER / WAL_RECOVERY_TARGET
+SET recovery_target_action = 'pause';  -- fail, requires restart
+ERROR:  parameter "recovery_target_action" cannot be changed without restarting the server
+RESET recovery_target_action;  -- fail, requires restart
+ERROR:  parameter "recovery_target_action" cannot be changed without restarting the server
+ALTER SYSTEM SET recovery_target_action = 'pause';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_action"
+ALTER SYSTEM RESET recovery_target_action;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_action"
+SET recovery_target_inclusive = OFF;  -- fail, requires restart
+ERROR:  parameter "recovery_target_inclusive" cannot be changed without restarting the server
+RESET recovery_target_inclusive;  -- fail, requires restart
+ERROR:  parameter "recovery_target_inclusive" cannot be changed without restarting the server
+ALTER SYSTEM SET recovery_target_inclusive = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_inclusive"
+ALTER SYSTEM RESET recovery_target_inclusive;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_inclusive"
+SET recovery_target_lsn = '16/B374D848';  -- fail, requires restart
+ERROR:  parameter "recovery_target_lsn" cannot be changed without restarting the server
+RESET recovery_target_lsn;  -- fail, requires restart
+ERROR:  parameter "recovery_target_lsn" cannot be changed without restarting the server
+ALTER SYSTEM SET recovery_target_lsn = '16/B374D848';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_lsn"
+ALTER SYSTEM RESET recovery_target_lsn;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_lsn"
+SET recovery_target_name = 'BonPoint';  -- fail, requires restart
+ERROR:  parameter "recovery_target_name" cannot be changed without restarting the server
+RESET recovery_target_name;  -- fail, requires restart
+ERROR:  parameter "recovery_target_name" cannot be changed without restarting the server
+ALTER SYSTEM SET recovery_target_name = 'BonPoint';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_name"
+ALTER SYSTEM RESET recovery_target_name;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_name"
+SET recovery_target_time = '2001-02-03 04:05:06.789 Europe/Helsinki';  -- fail, requires restart
+ERROR:  parameter "recovery_target_time" cannot be changed without restarting the server
+RESET recovery_target_time;  -- fail, requires restart
+ERROR:  parameter "recovery_target_time" cannot be changed without restarting the server
+ALTER SYSTEM SET recovery_target_time = '2001-02-03 04:05:06.789 Europe/Helsinki';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_time"
+ALTER SYSTEM RESET recovery_target_time;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_time"
+SET recovery_target_timeline = 'latest';  -- fail, requires restart
+ERROR:  parameter "recovery_target_timeline" cannot be changed without restarting the server
+RESET recovery_target_timeline;  -- fail, requires restart
+ERROR:  parameter "recovery_target_timeline" cannot be changed without restarting the server
+ALTER SYSTEM SET recovery_target_timeline = 'latest';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_timeline"
+ALTER SYSTEM RESET recovery_target_timeline;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_timeline"
+SET recovery_target_xid = '12345678';  -- fail, requires restart
+ERROR:  parameter "recovery_target_xid" cannot be changed without restarting the server
+RESET recovery_target_xid;  -- fail, requires restart
+ERROR:  parameter "recovery_target_xid" cannot be changed without restarting the server
+ALTER SYSTEM SET recovery_target_xid = '12345678';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_xid"
+ALTER SYSTEM RESET recovery_target_xid;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_target_xid"
+-- PGC_POSTMASTER / WAL_SETTINGS
+SET wal_buffers = 50;  -- fail, requires restart
+ERROR:  parameter "wal_buffers" cannot be changed without restarting the server
+RESET wal_buffers;  -- fail, requires restart
+ERROR:  parameter "wal_buffers" cannot be changed without restarting the server
+ALTER SYSTEM SET wal_buffers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_buffers"
+ALTER SYSTEM RESET wal_buffers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_buffers"
+SET wal_level = 'replica';  -- fail, requires restart
+ERROR:  parameter "wal_level" cannot be changed without restarting the server
+RESET wal_level;  -- fail, requires restart
+ERROR:  parameter "wal_level" cannot be changed without restarting the server
+ALTER SYSTEM SET wal_level = 'replica';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_level"
+ALTER SYSTEM RESET wal_level;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_level"
+SET wal_log_hints = OFF;  -- fail, requires restart
+ERROR:  parameter "wal_log_hints" cannot be changed without restarting the server
+RESET wal_log_hints;  -- fail, requires restart
+ERROR:  parameter "wal_log_hints" cannot be changed without restarting the server
+ALTER SYSTEM SET wal_log_hints = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_log_hints"
+ALTER SYSTEM RESET wal_log_hints;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_log_hints"
+-- PGC_SIGHUP / AUTOVACUUM
+SET autovacuum = OFF;  -- fail, requires reload
+ERROR:  parameter "autovacuum" cannot be changed now
+RESET autovacuum;  -- fail, requires reload
+ERROR:  parameter "autovacuum" cannot be changed now
+ALTER SYSTEM SET autovacuum = OFF;  -- ok
+ALTER SYSTEM RESET autovacuum;  -- ok
+SET autovacuum_analyze_scale_factor = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_analyze_scale_factor" cannot be changed now
+RESET autovacuum_analyze_scale_factor;  -- fail, requires reload
+ERROR:  parameter "autovacuum_analyze_scale_factor" cannot be changed now
+ALTER SYSTEM SET autovacuum_analyze_scale_factor = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_analyze_scale_factor;  -- ok
+SET autovacuum_analyze_threshold = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_analyze_threshold" cannot be changed now
+RESET autovacuum_analyze_threshold;  -- fail, requires reload
+ERROR:  parameter "autovacuum_analyze_threshold" cannot be changed now
+ALTER SYSTEM SET autovacuum_analyze_threshold = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_analyze_threshold;  -- ok
+SET autovacuum_naptime = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_naptime" cannot be changed now
+RESET autovacuum_naptime;  -- fail, requires reload
+ERROR:  parameter "autovacuum_naptime" cannot be changed now
+ALTER SYSTEM SET autovacuum_naptime = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_naptime;  -- ok
+SET autovacuum_vacuum_cost_delay = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_cost_delay" cannot be changed now
+RESET autovacuum_vacuum_cost_delay;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_cost_delay" cannot be changed now
+ALTER SYSTEM SET autovacuum_vacuum_cost_delay = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_cost_delay;  -- ok
+SET autovacuum_vacuum_cost_limit = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_cost_limit" cannot be changed now
+RESET autovacuum_vacuum_cost_limit;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_cost_limit" cannot be changed now
+ALTER SYSTEM SET autovacuum_vacuum_cost_limit = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_cost_limit;  -- ok
+SET autovacuum_vacuum_insert_scale_factor = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_insert_scale_factor" cannot be changed now
+RESET autovacuum_vacuum_insert_scale_factor;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_insert_scale_factor" cannot be changed now
+ALTER SYSTEM SET autovacuum_vacuum_insert_scale_factor = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_insert_scale_factor;  -- ok
+SET autovacuum_vacuum_insert_threshold = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_insert_threshold" cannot be changed now
+RESET autovacuum_vacuum_insert_threshold;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_insert_threshold" cannot be changed now
+ALTER SYSTEM SET autovacuum_vacuum_insert_threshold = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_insert_threshold;  -- ok
+SET autovacuum_vacuum_scale_factor = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_scale_factor" cannot be changed now
+RESET autovacuum_vacuum_scale_factor;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_scale_factor" cannot be changed now
+ALTER SYSTEM SET autovacuum_vacuum_scale_factor = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_scale_factor;  -- ok
+SET autovacuum_vacuum_threshold = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_threshold" cannot be changed now
+RESET autovacuum_vacuum_threshold;  -- fail, requires reload
+ERROR:  parameter "autovacuum_vacuum_threshold" cannot be changed now
+ALTER SYSTEM SET autovacuum_vacuum_threshold = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_threshold;  -- ok
+-- PGC_SIGHUP / CONN_AUTH_AUTH
+SET authentication_timeout = 50;  -- fail, requires reload
+ERROR:  parameter "authentication_timeout" cannot be changed now
+RESET authentication_timeout;  -- fail, requires reload
+ERROR:  parameter "authentication_timeout" cannot be changed now
+ALTER SYSTEM SET authentication_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "authentication_timeout"
+ALTER SYSTEM RESET authentication_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "authentication_timeout"
+SET db_user_namespace = OFF;  -- fail, requires reload
+ERROR:  parameter "db_user_namespace" cannot be changed now
+RESET db_user_namespace;  -- fail, requires reload
+ERROR:  parameter "db_user_namespace" cannot be changed now
+ALTER SYSTEM SET db_user_namespace = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "db_user_namespace"
+ALTER SYSTEM RESET db_user_namespace;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "db_user_namespace"
+SET krb_caseins_users = OFF;  -- fail, requires reload
+ERROR:  parameter "krb_caseins_users" cannot be changed now
+RESET krb_caseins_users;  -- fail, requires reload
+ERROR:  parameter "krb_caseins_users" cannot be changed now
+ALTER SYSTEM SET krb_caseins_users = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_caseins_users"
+ALTER SYSTEM RESET krb_caseins_users;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_caseins_users"
+SET krb_server_keyfile = 'krb/server.key';  -- fail, requires reload
+ERROR:  parameter "krb_server_keyfile" cannot be changed now
+RESET krb_server_keyfile;  -- fail, requires reload
+ERROR:  parameter "krb_server_keyfile" cannot be changed now
+ALTER SYSTEM SET krb_server_keyfile = 'krb/server.key';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_server_keyfile"
+ALTER SYSTEM RESET krb_server_keyfile;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "krb_server_keyfile"
+-- PGC_SIGHUP / CONN_AUTH_SSL
+SET ssl_ca_file = 'ca/server.ca';  -- fail, requires reload
+ERROR:  parameter "ssl_ca_file" cannot be changed now
+RESET ssl_ca_file;  -- fail, requires reload
+ERROR:  parameter "ssl_ca_file" cannot be changed now
+ALTER SYSTEM SET ssl_ca_file = 'ca/server.ca';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ca_file"
+ALTER SYSTEM RESET ssl_ca_file;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ca_file"
+SET ssl_cert_file = 'crt/server.crt';  -- fail, requires reload
+ERROR:  parameter "ssl_cert_file" cannot be changed now
+RESET ssl_cert_file;  -- fail, requires reload
+ERROR:  parameter "ssl_cert_file" cannot be changed now
+ALTER SYSTEM SET ssl_cert_file = 'crt/server.crt';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_cert_file"
+ALTER SYSTEM RESET ssl_cert_file;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_cert_file"
+SET ssl_ciphers = 'none';  -- fail, requires reload
+ERROR:  parameter "ssl_ciphers" cannot be changed now
+RESET ssl_ciphers;  -- fail, requires reload
+ERROR:  parameter "ssl_ciphers" cannot be changed now
+ALTER SYSTEM SET ssl_ciphers = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ciphers"
+ALTER SYSTEM RESET ssl_ciphers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ciphers"
+SET ssl_crl_dir = 'crl/';  -- fail, requires reload
+ERROR:  parameter "ssl_crl_dir" cannot be changed now
+RESET ssl_crl_dir;  -- fail, requires reload
+ERROR:  parameter "ssl_crl_dir" cannot be changed now
+ALTER SYSTEM SET ssl_crl_dir = 'crl/';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_dir"
+ALTER SYSTEM RESET ssl_crl_dir;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_dir"
+SET ssl_crl_file = 'crl/server.crl';  -- fail, requires reload
+ERROR:  parameter "ssl_crl_file" cannot be changed now
+RESET ssl_crl_file;  -- fail, requires reload
+ERROR:  parameter "ssl_crl_file" cannot be changed now
+ALTER SYSTEM SET ssl_crl_file = 'crl/server.crl';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_file"
+ALTER SYSTEM RESET ssl_crl_file;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_crl_file"
+SET ssl_dh_params_file = 'ssl/params';  -- fail, requires reload
+ERROR:  parameter "ssl_dh_params_file" cannot be changed now
+RESET ssl_dh_params_file;  -- fail, requires reload
+ERROR:  parameter "ssl_dh_params_file" cannot be changed now
+ALTER SYSTEM SET ssl_dh_params_file = 'ssl/params';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_dh_params_file"
+ALTER SYSTEM RESET ssl_dh_params_file;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_dh_params_file"
+SET ssl_ecdh_curve = 'none';  -- fail, requires reload
+ERROR:  parameter "ssl_ecdh_curve" cannot be changed now
+RESET ssl_ecdh_curve;  -- fail, requires reload
+ERROR:  parameter "ssl_ecdh_curve" cannot be changed now
+ALTER SYSTEM SET ssl_ecdh_curve = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ecdh_curve"
+ALTER SYSTEM RESET ssl_ecdh_curve;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_ecdh_curve"
+SET ssl_key_file = 'crl/server.key';  -- fail, requires reload
+ERROR:  parameter "ssl_key_file" cannot be changed now
+RESET ssl_key_file;  -- fail, requires reload
+ERROR:  parameter "ssl_key_file" cannot be changed now
+ALTER SYSTEM SET ssl_key_file = 'crl/server.key';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_key_file"
+ALTER SYSTEM RESET ssl_key_file;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_key_file"
+SET ssl_min_protocol_version = 'TLSv1.2';  -- fail, requires reload
+ERROR:  parameter "ssl_min_protocol_version" cannot be changed now
+RESET ssl_min_protocol_version;  -- fail, requires reload
+ERROR:  parameter "ssl_min_protocol_version" cannot be changed now
+ALTER SYSTEM SET ssl_min_protocol_version = 'TLSv1.2';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_min_protocol_version"
+ALTER SYSTEM RESET ssl_min_protocol_version;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_min_protocol_version"
+SET ssl_passphrase_command = '/bin/passphrase';  -- fail, requires reload
+ERROR:  parameter "ssl_passphrase_command" cannot be changed now
+RESET ssl_passphrase_command;  -- fail, requires reload
+ERROR:  parameter "ssl_passphrase_command" cannot be changed now
+ALTER SYSTEM SET ssl_passphrase_command = '/bin/passphrase';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command"
+ALTER SYSTEM RESET ssl_passphrase_command;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command"
+SET ssl_passphrase_command_supports_reload = OFF;  -- fail, requires reload
+ERROR:  parameter "ssl_passphrase_command_supports_reload" cannot be changed now
+RESET ssl_passphrase_command_supports_reload;  -- fail, requires reload
+ERROR:  parameter "ssl_passphrase_command_supports_reload" cannot be changed now
+ALTER SYSTEM SET ssl_passphrase_command_supports_reload = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command_supports_reload"
+ALTER SYSTEM RESET ssl_passphrase_command_supports_reload;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_passphrase_command_supports_reload"
+SET ssl_prefer_server_ciphers = OFF;  -- fail, requires reload
+ERROR:  parameter "ssl_prefer_server_ciphers" cannot be changed now
+RESET ssl_prefer_server_ciphers;  -- fail, requires reload
+ERROR:  parameter "ssl_prefer_server_ciphers" cannot be changed now
+ALTER SYSTEM SET ssl_prefer_server_ciphers = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_prefer_server_ciphers"
+ALTER SYSTEM RESET ssl_prefer_server_ciphers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ssl_prefer_server_ciphers"
+-- PGC_SIGHUP / DEVELOPER_OPTIONS
+SET pre_auth_delay = 50;  -- fail, requires reload
+ERROR:  parameter "pre_auth_delay" cannot be changed now
+RESET pre_auth_delay;  -- fail, requires reload
+ERROR:  parameter "pre_auth_delay" cannot be changed now
+ALTER SYSTEM SET pre_auth_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "pre_auth_delay"
+ALTER SYSTEM RESET pre_auth_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "pre_auth_delay"
+SET remove_temp_files_after_crash = OFF;  -- fail, requires reload
+ERROR:  parameter "remove_temp_files_after_crash" cannot be changed now
+RESET remove_temp_files_after_crash;  -- fail, requires reload
+ERROR:  parameter "remove_temp_files_after_crash" cannot be changed now
+ALTER SYSTEM SET remove_temp_files_after_crash = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "remove_temp_files_after_crash"
+ALTER SYSTEM RESET remove_temp_files_after_crash;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "remove_temp_files_after_crash"
+SET trace_recovery_messages = 'log';  -- fail, requires reload
+ERROR:  parameter "trace_recovery_messages" cannot be changed now
+RESET trace_recovery_messages;  -- fail, requires reload
+ERROR:  parameter "trace_recovery_messages" cannot be changed now
+ALTER SYSTEM SET trace_recovery_messages = 'log';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_recovery_messages"
+ALTER SYSTEM RESET trace_recovery_messages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_recovery_messages"
+-- PGC_SIGHUP / ERROR_HANDLING_OPTIONS
+SET recovery_init_sync_method = 'fsync';  -- fail, requires reload
+ERROR:  parameter "recovery_init_sync_method" cannot be changed now
+RESET recovery_init_sync_method;  -- fail, requires reload
+ERROR:  parameter "recovery_init_sync_method" cannot be changed now
+ALTER SYSTEM SET recovery_init_sync_method = 'fsync';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_init_sync_method"
+ALTER SYSTEM RESET recovery_init_sync_method;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_init_sync_method"
+SET restart_after_crash = OFF;  -- fail, requires reload
+ERROR:  parameter "restart_after_crash" cannot be changed now
+RESET restart_after_crash;  -- fail, requires reload
+ERROR:  parameter "restart_after_crash" cannot be changed now
+ALTER SYSTEM SET restart_after_crash = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restart_after_crash"
+ALTER SYSTEM RESET restart_after_crash;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restart_after_crash"
+-- PGC_SIGHUP / LOCK_MANAGEMENT
+SET max_pred_locks_per_page = 50;  -- fail, requires reload
+ERROR:  parameter "max_pred_locks_per_page" cannot be changed now
+RESET max_pred_locks_per_page;  -- fail, requires reload
+ERROR:  parameter "max_pred_locks_per_page" cannot be changed now
+ALTER SYSTEM SET max_pred_locks_per_page = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_page"
+ALTER SYSTEM RESET max_pred_locks_per_page;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_page"
+SET max_pred_locks_per_relation = 50;  -- fail, requires reload
+ERROR:  parameter "max_pred_locks_per_relation" cannot be changed now
+RESET max_pred_locks_per_relation;  -- fail, requires reload
+ERROR:  parameter "max_pred_locks_per_relation" cannot be changed now
+ALTER SYSTEM SET max_pred_locks_per_relation = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_relation"
+ALTER SYSTEM RESET max_pred_locks_per_relation;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_pred_locks_per_relation"
+-- PGC_SIGHUP / LOGGING_WHAT
+SET log_autovacuum_min_duration = 50;  -- fail, requires reload
+ERROR:  parameter "log_autovacuum_min_duration" cannot be changed now
+RESET log_autovacuum_min_duration;  -- fail, requires reload
+ERROR:  parameter "log_autovacuum_min_duration" cannot be changed now
+ALTER SYSTEM SET log_autovacuum_min_duration = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_autovacuum_min_duration"
+ALTER SYSTEM RESET log_autovacuum_min_duration;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_autovacuum_min_duration"
+SET log_checkpoints = OFF;  -- fail, requires reload
+ERROR:  parameter "log_checkpoints" cannot be changed now
+RESET log_checkpoints;  -- fail, requires reload
+ERROR:  parameter "log_checkpoints" cannot be changed now
+ALTER SYSTEM SET log_checkpoints = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_checkpoints"
+ALTER SYSTEM RESET log_checkpoints;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_checkpoints"
+SET log_hostname = OFF;  -- fail, requires reload
+ERROR:  parameter "log_hostname" cannot be changed now
+RESET log_hostname;  -- fail, requires reload
+ERROR:  parameter "log_hostname" cannot be changed now
+ALTER SYSTEM SET log_hostname = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_hostname"
+ALTER SYSTEM RESET log_hostname;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_hostname"
+SET log_line_prefix = '%m [%p] ';  -- fail, requires reload
+ERROR:  parameter "log_line_prefix" cannot be changed now
+RESET log_line_prefix;  -- fail, requires reload
+ERROR:  parameter "log_line_prefix" cannot be changed now
+ALTER SYSTEM SET log_line_prefix = '%m [%p] ';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_line_prefix"
+ALTER SYSTEM RESET log_line_prefix;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_line_prefix"
+SET log_recovery_conflict_waits = OFF;  -- fail, requires reload
+ERROR:  parameter "log_recovery_conflict_waits" cannot be changed now
+RESET log_recovery_conflict_waits;  -- fail, requires reload
+ERROR:  parameter "log_recovery_conflict_waits" cannot be changed now
+ALTER SYSTEM SET log_recovery_conflict_waits = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_recovery_conflict_waits"
+ALTER SYSTEM RESET log_recovery_conflict_waits;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_recovery_conflict_waits"
+SET log_timezone = 'Europe/Helsinki';  -- fail, requires reload
+ERROR:  parameter "log_timezone" cannot be changed now
+RESET log_timezone;  -- fail, requires reload
+ERROR:  parameter "log_timezone" cannot be changed now
+ALTER SYSTEM SET log_timezone = 'Europe/Helsinki';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_timezone"
+ALTER SYSTEM RESET log_timezone;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_timezone"
+-- PGC_SIGHUP / LOGGING_WHERE
+SET log_directory = 'log';  -- fail, requires reload
+ERROR:  parameter "log_directory" cannot be changed now
+RESET log_directory;  -- fail, requires reload
+ERROR:  parameter "log_directory" cannot be changed now
+ALTER SYSTEM SET log_directory = 'log';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_directory"
+ALTER SYSTEM RESET log_directory;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_directory"
+SET log_file_mode = 50;  -- fail, requires reload
+ERROR:  parameter "log_file_mode" cannot be changed now
+RESET log_file_mode;  -- fail, requires reload
+ERROR:  parameter "log_file_mode" cannot be changed now
+ALTER SYSTEM SET log_file_mode = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_file_mode"
+ALTER SYSTEM RESET log_file_mode;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_file_mode"
+SET log_filename = 'postgresql-%Y-%m-%d_%H%M%S.log';  -- fail, requires reload
+ERROR:  parameter "log_filename" cannot be changed now
+RESET log_filename;  -- fail, requires reload
+ERROR:  parameter "log_filename" cannot be changed now
+ALTER SYSTEM SET log_filename = 'postgresql-%Y-%m-%d_%H%M%S.log';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_filename"
+ALTER SYSTEM RESET log_filename;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_filename"
+SET log_rotation_age = 50;  -- fail, requires reload
+ERROR:  parameter "log_rotation_age" cannot be changed now
+RESET log_rotation_age;  -- fail, requires reload
+ERROR:  parameter "log_rotation_age" cannot be changed now
+ALTER SYSTEM SET log_rotation_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_age"
+ALTER SYSTEM RESET log_rotation_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_age"
+SET log_rotation_size = 50;  -- fail, requires reload
+ERROR:  parameter "log_rotation_size" cannot be changed now
+RESET log_rotation_size;  -- fail, requires reload
+ERROR:  parameter "log_rotation_size" cannot be changed now
+ALTER SYSTEM SET log_rotation_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_size"
+ALTER SYSTEM RESET log_rotation_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_rotation_size"
+SET log_truncate_on_rotation = OFF;  -- fail, requires reload
+ERROR:  parameter "log_truncate_on_rotation" cannot be changed now
+RESET log_truncate_on_rotation;  -- fail, requires reload
+ERROR:  parameter "log_truncate_on_rotation" cannot be changed now
+ALTER SYSTEM SET log_truncate_on_rotation = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_truncate_on_rotation"
+ALTER SYSTEM RESET log_truncate_on_rotation;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_truncate_on_rotation"
+SET syslog_ident = 'postgres';  -- fail, requires reload
+ERROR:  parameter "syslog_ident" cannot be changed now
+RESET syslog_ident;  -- fail, requires reload
+ERROR:  parameter "syslog_ident" cannot be changed now
+ALTER SYSTEM SET syslog_ident = 'postgres';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_ident"
+ALTER SYSTEM RESET syslog_ident;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_ident"
+SET syslog_sequence_numbers = OFF;  -- fail, requires reload
+ERROR:  parameter "syslog_sequence_numbers" cannot be changed now
+RESET syslog_sequence_numbers;  -- fail, requires reload
+ERROR:  parameter "syslog_sequence_numbers" cannot be changed now
+ALTER SYSTEM SET syslog_sequence_numbers = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_sequence_numbers"
+ALTER SYSTEM RESET syslog_sequence_numbers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_sequence_numbers"
+SET syslog_split_messages = OFF;  -- fail, requires reload
+ERROR:  parameter "syslog_split_messages" cannot be changed now
+RESET syslog_split_messages;  -- fail, requires reload
+ERROR:  parameter "syslog_split_messages" cannot be changed now
+ALTER SYSTEM SET syslog_split_messages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_split_messages"
+ALTER SYSTEM RESET syslog_split_messages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "syslog_split_messages"
+-- PGC_SIGHUP / REPLICATION_PRIMARY
+SET synchronous_standby_names = 'fee, fi, fo, fum';  -- fail, requires reload
+ERROR:  parameter "synchronous_standby_names" cannot be changed now
+RESET synchronous_standby_names;  -- fail, requires reload
+ERROR:  parameter "synchronous_standby_names" cannot be changed now
+ALTER SYSTEM SET synchronous_standby_names = 'fee, fi, fo, fum';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronous_standby_names"
+ALTER SYSTEM RESET synchronous_standby_names;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronous_standby_names"
+SET vacuum_defer_cleanup_age = 50;  -- fail, requires reload
+ERROR:  parameter "vacuum_defer_cleanup_age" cannot be changed now
+RESET vacuum_defer_cleanup_age;  -- fail, requires reload
+ERROR:  parameter "vacuum_defer_cleanup_age" cannot be changed now
+ALTER SYSTEM SET vacuum_defer_cleanup_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_defer_cleanup_age"
+ALTER SYSTEM RESET vacuum_defer_cleanup_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_defer_cleanup_age"
+-- PGC_SIGHUP / REPLICATION_SENDING
+SET max_slot_wal_keep_size = 50;  -- fail, requires reload
+ERROR:  parameter "max_slot_wal_keep_size" cannot be changed now
+RESET max_slot_wal_keep_size;  -- fail, requires reload
+ERROR:  parameter "max_slot_wal_keep_size" cannot be changed now
+ALTER SYSTEM SET max_slot_wal_keep_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_slot_wal_keep_size"
+ALTER SYSTEM RESET max_slot_wal_keep_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_slot_wal_keep_size"
+SET wal_keep_size = 50;  -- fail, requires reload
+ERROR:  parameter "wal_keep_size" cannot be changed now
+RESET wal_keep_size;  -- fail, requires reload
+ERROR:  parameter "wal_keep_size" cannot be changed now
+ALTER SYSTEM SET wal_keep_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_keep_size"
+ALTER SYSTEM RESET wal_keep_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_keep_size"
+-- PGC_SIGHUP / REPLICATION_STANDBY
+SET hot_standby_feedback = OFF;  -- fail, requires reload
+ERROR:  parameter "hot_standby_feedback" cannot be changed now
+RESET hot_standby_feedback;  -- fail, requires reload
+ERROR:  parameter "hot_standby_feedback" cannot be changed now
+ALTER SYSTEM SET hot_standby_feedback = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hot_standby_feedback"
+ALTER SYSTEM RESET hot_standby_feedback;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hot_standby_feedback"
+SET max_standby_archive_delay = 50;  -- fail, requires reload
+ERROR:  parameter "max_standby_archive_delay" cannot be changed now
+RESET max_standby_archive_delay;  -- fail, requires reload
+ERROR:  parameter "max_standby_archive_delay" cannot be changed now
+ALTER SYSTEM SET max_standby_archive_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_standby_archive_delay"
+ALTER SYSTEM RESET max_standby_archive_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_standby_archive_delay"
+SET max_standby_streaming_delay = 50;  -- fail, requires reload
+ERROR:  parameter "max_standby_streaming_delay" cannot be changed now
+RESET max_standby_streaming_delay;  -- fail, requires reload
+ERROR:  parameter "max_standby_streaming_delay" cannot be changed now
+ALTER SYSTEM SET max_standby_streaming_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_standby_streaming_delay"
+ALTER SYSTEM RESET max_standby_streaming_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_standby_streaming_delay"
+SET primary_conninfo = 'postgresql://other@localhost/otherdb?connect_timeout=10&application_name=myapp';  -- fail, requires reload
+ERROR:  parameter "primary_conninfo" cannot be changed now
+RESET primary_conninfo;  -- fail, requires reload
+ERROR:  parameter "primary_conninfo" cannot be changed now
+ALTER SYSTEM SET primary_conninfo = 'postgresql://other@localhost/otherdb?connect_timeout=10&application_name=myapp';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "primary_conninfo"
+ALTER SYSTEM RESET primary_conninfo;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "primary_conninfo"
+SET primary_slot_name = 'bonne_fente';  -- fail, requires reload
+ERROR:  parameter "primary_slot_name" cannot be changed now
+RESET primary_slot_name;  -- fail, requires reload
+ERROR:  parameter "primary_slot_name" cannot be changed now
+ALTER SYSTEM SET primary_slot_name = 'bonne_fente';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "primary_slot_name"
+ALTER SYSTEM RESET primary_slot_name;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "primary_slot_name"
+SET promote_trigger_file = 'promote.trigger';  -- fail, requires reload
+ERROR:  parameter "promote_trigger_file" cannot be changed now
+RESET promote_trigger_file;  -- fail, requires reload
+ERROR:  parameter "promote_trigger_file" cannot be changed now
+ALTER SYSTEM SET promote_trigger_file = 'promote.trigger';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "promote_trigger_file"
+ALTER SYSTEM RESET promote_trigger_file;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "promote_trigger_file"
+SET recovery_min_apply_delay = 50;  -- fail, requires reload
+ERROR:  parameter "recovery_min_apply_delay" cannot be changed now
+RESET recovery_min_apply_delay;  -- fail, requires reload
+ERROR:  parameter "recovery_min_apply_delay" cannot be changed now
+ALTER SYSTEM SET recovery_min_apply_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_min_apply_delay"
+ALTER SYSTEM RESET recovery_min_apply_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_min_apply_delay"
+SET wal_receiver_create_temp_slot = OFF;  -- fail, requires reload
+ERROR:  parameter "wal_receiver_create_temp_slot" cannot be changed now
+RESET wal_receiver_create_temp_slot;  -- fail, requires reload
+ERROR:  parameter "wal_receiver_create_temp_slot" cannot be changed now
+ALTER SYSTEM SET wal_receiver_create_temp_slot = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_receiver_create_temp_slot"
+ALTER SYSTEM RESET wal_receiver_create_temp_slot;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_receiver_create_temp_slot"
+SET wal_receiver_status_interval = 50;  -- fail, requires reload
+ERROR:  parameter "wal_receiver_status_interval" cannot be changed now
+RESET wal_receiver_status_interval;  -- fail, requires reload
+ERROR:  parameter "wal_receiver_status_interval" cannot be changed now
+ALTER SYSTEM SET wal_receiver_status_interval = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_receiver_status_interval"
+ALTER SYSTEM RESET wal_receiver_status_interval;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_receiver_status_interval"
+SET wal_receiver_timeout = 50;  -- fail, requires reload
+ERROR:  parameter "wal_receiver_timeout" cannot be changed now
+RESET wal_receiver_timeout;  -- fail, requires reload
+ERROR:  parameter "wal_receiver_timeout" cannot be changed now
+ALTER SYSTEM SET wal_receiver_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_receiver_timeout"
+ALTER SYSTEM RESET wal_receiver_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_receiver_timeout"
+SET wal_retrieve_retry_interval = 50;  -- fail, requires reload
+ERROR:  parameter "wal_retrieve_retry_interval" cannot be changed now
+RESET wal_retrieve_retry_interval;  -- fail, requires reload
+ERROR:  parameter "wal_retrieve_retry_interval" cannot be changed now
+ALTER SYSTEM SET wal_retrieve_retry_interval = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_retrieve_retry_interval"
+ALTER SYSTEM RESET wal_retrieve_retry_interval;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_retrieve_retry_interval"
+-- PGC_SIGHUP / REPLICATION_SUBSCRIBERS
+SET max_sync_workers_per_subscription = 50;  -- fail, requires reload
+ERROR:  parameter "max_sync_workers_per_subscription" cannot be changed now
+RESET max_sync_workers_per_subscription;  -- fail, requires reload
+ERROR:  parameter "max_sync_workers_per_subscription" cannot be changed now
+ALTER SYSTEM SET max_sync_workers_per_subscription = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_sync_workers_per_subscription"
+ALTER SYSTEM RESET max_sync_workers_per_subscription;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_sync_workers_per_subscription"
+-- PGC_SIGHUP / RESOURCES_BGWRITER
+SET bgwriter_delay = 50;  -- fail, requires reload
+ERROR:  parameter "bgwriter_delay" cannot be changed now
+RESET bgwriter_delay;  -- fail, requires reload
+ERROR:  parameter "bgwriter_delay" cannot be changed now
+ALTER SYSTEM SET bgwriter_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_delay"
+ALTER SYSTEM RESET bgwriter_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_delay"
+SET bgwriter_flush_after = 50;  -- fail, requires reload
+ERROR:  parameter "bgwriter_flush_after" cannot be changed now
+RESET bgwriter_flush_after;  -- fail, requires reload
+ERROR:  parameter "bgwriter_flush_after" cannot be changed now
+ALTER SYSTEM SET bgwriter_flush_after = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_flush_after"
+ALTER SYSTEM RESET bgwriter_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_flush_after"
+SET bgwriter_lru_maxpages = 50;  -- fail, requires reload
+ERROR:  parameter "bgwriter_lru_maxpages" cannot be changed now
+RESET bgwriter_lru_maxpages;  -- fail, requires reload
+ERROR:  parameter "bgwriter_lru_maxpages" cannot be changed now
+ALTER SYSTEM SET bgwriter_lru_maxpages = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_maxpages"
+ALTER SYSTEM RESET bgwriter_lru_maxpages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_maxpages"
+SET bgwriter_lru_multiplier = 5;  -- fail, requires reload
+ERROR:  parameter "bgwriter_lru_multiplier" cannot be changed now
+RESET bgwriter_lru_multiplier;  -- fail, requires reload
+ERROR:  parameter "bgwriter_lru_multiplier" cannot be changed now
+ALTER SYSTEM SET bgwriter_lru_multiplier = 5;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_multiplier"
+ALTER SYSTEM RESET bgwriter_lru_multiplier;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bgwriter_lru_multiplier"
+-- PGC_SIGHUP / RESOURCES_MEM
+SET autovacuum_work_mem = 50;  -- fail, requires reload
+ERROR:  parameter "autovacuum_work_mem" cannot be changed now
+RESET autovacuum_work_mem;  -- fail, requires reload
+ERROR:  parameter "autovacuum_work_mem" cannot be changed now
+ALTER SYSTEM SET autovacuum_work_mem = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_work_mem"
+ALTER SYSTEM RESET autovacuum_work_mem;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "autovacuum_work_mem"
+-- PGC_SIGHUP / STATS_COLLECTOR
+SET stats_temp_directory = 'pg_stat_tmp';  -- fail, requires reload
+ERROR:  parameter "stats_temp_directory" cannot be changed now
+RESET stats_temp_directory;  -- fail, requires reload
+ERROR:  parameter "stats_temp_directory" cannot be changed now
+ALTER SYSTEM SET stats_temp_directory = 'pg_stat_tmp';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "stats_temp_directory"
+ALTER SYSTEM RESET stats_temp_directory;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "stats_temp_directory"
+-- PGC_SIGHUP / WAL_ARCHIVE_RECOVERY
+SET archive_cleanup_command = '/bin/cleanup my stuff';  -- fail, requires reload
+ERROR:  parameter "archive_cleanup_command" cannot be changed now
+RESET archive_cleanup_command;  -- fail, requires reload
+ERROR:  parameter "archive_cleanup_command" cannot be changed now
+ALTER SYSTEM SET archive_cleanup_command = '/bin/cleanup my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_cleanup_command"
+ALTER SYSTEM RESET archive_cleanup_command;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_cleanup_command"
+SET recovery_end_command = '/bin/recover my stuff';  -- fail, requires reload
+ERROR:  parameter "recovery_end_command" cannot be changed now
+RESET recovery_end_command;  -- fail, requires reload
+ERROR:  parameter "recovery_end_command" cannot be changed now
+ALTER SYSTEM SET recovery_end_command = '/bin/recover my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_end_command"
+ALTER SYSTEM RESET recovery_end_command;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "recovery_end_command"
+SET restore_command = '/bin/restore my stuff';  -- fail, requires reload
+ERROR:  parameter "restore_command" cannot be changed now
+RESET restore_command;  -- fail, requires reload
+ERROR:  parameter "restore_command" cannot be changed now
+ALTER SYSTEM SET restore_command = '/bin/restore my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restore_command"
+ALTER SYSTEM RESET restore_command;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "restore_command"
+-- PGC_SIGHUP / WAL_ARCHIVING
+SET archive_command = '/bin/archive my stuff';  -- fail, requires reload
+ERROR:  parameter "archive_command" cannot be changed now
+RESET archive_command;  -- fail, requires reload
+ERROR:  parameter "archive_command" cannot be changed now
+ALTER SYSTEM SET archive_command = '/bin/archive my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_command"
+ALTER SYSTEM RESET archive_command;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_command"
+SET archive_timeout = 50;  -- fail, requires reload
+ERROR:  parameter "archive_timeout" cannot be changed now
+RESET archive_timeout;  -- fail, requires reload
+ERROR:  parameter "archive_timeout" cannot be changed now
+ALTER SYSTEM SET archive_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_timeout"
+ALTER SYSTEM RESET archive_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "archive_timeout"
+-- PGC_SIGHUP / WAL_CHECKPOINTS
+SET checkpoint_completion_target = 0;  -- fail, requires reload
+ERROR:  parameter "checkpoint_completion_target" cannot be changed now
+RESET checkpoint_completion_target;  -- fail, requires reload
+ERROR:  parameter "checkpoint_completion_target" cannot be changed now
+ALTER SYSTEM SET checkpoint_completion_target = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_completion_target"
+ALTER SYSTEM RESET checkpoint_completion_target;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_completion_target"
+SET checkpoint_flush_after = 50;  -- fail, requires reload
+ERROR:  parameter "checkpoint_flush_after" cannot be changed now
+RESET checkpoint_flush_after;  -- fail, requires reload
+ERROR:  parameter "checkpoint_flush_after" cannot be changed now
+ALTER SYSTEM SET checkpoint_flush_after = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_flush_after"
+ALTER SYSTEM RESET checkpoint_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_flush_after"
+SET checkpoint_timeout = 50;  -- fail, requires reload
+ERROR:  parameter "checkpoint_timeout" cannot be changed now
+RESET checkpoint_timeout;  -- fail, requires reload
+ERROR:  parameter "checkpoint_timeout" cannot be changed now
+ALTER SYSTEM SET checkpoint_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_timeout"
+ALTER SYSTEM RESET checkpoint_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_timeout"
+SET checkpoint_warning = 50;  -- fail, requires reload
+ERROR:  parameter "checkpoint_warning" cannot be changed now
+RESET checkpoint_warning;  -- fail, requires reload
+ERROR:  parameter "checkpoint_warning" cannot be changed now
+ALTER SYSTEM SET checkpoint_warning = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_warning"
+ALTER SYSTEM RESET checkpoint_warning;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "checkpoint_warning"
+SET max_wal_size = 50;  -- fail, requires reload
+ERROR:  parameter "max_wal_size" cannot be changed now
+RESET max_wal_size;  -- fail, requires reload
+ERROR:  parameter "max_wal_size" cannot be changed now
+ALTER SYSTEM SET max_wal_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_wal_size"
+ALTER SYSTEM RESET max_wal_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_wal_size"
+SET min_wal_size = 50;  -- fail, requires reload
+ERROR:  parameter "min_wal_size" cannot be changed now
+RESET min_wal_size;  -- fail, requires reload
+ERROR:  parameter "min_wal_size" cannot be changed now
+ALTER SYSTEM SET min_wal_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_wal_size"
+ALTER SYSTEM RESET min_wal_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_wal_size"
+-- PGC_SIGHUP / WAL_SETTINGS
+SET fsync = OFF;  -- fail, requires reload
+ERROR:  parameter "fsync" cannot be changed now
+RESET fsync;  -- fail, requires reload
+ERROR:  parameter "fsync" cannot be changed now
+ALTER SYSTEM SET fsync = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "fsync"
+ALTER SYSTEM RESET fsync;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "fsync"
+SET full_page_writes = OFF;  -- fail, requires reload
+ERROR:  parameter "full_page_writes" cannot be changed now
+RESET full_page_writes;  -- fail, requires reload
+ERROR:  parameter "full_page_writes" cannot be changed now
+ALTER SYSTEM SET full_page_writes = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "full_page_writes"
+ALTER SYSTEM RESET full_page_writes;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "full_page_writes"
+SET wal_sync_method = 'open_datasync';  -- fail, requires reload
+ERROR:  parameter "wal_sync_method" cannot be changed now
+RESET wal_sync_method;  -- fail, requires reload
+ERROR:  parameter "wal_sync_method" cannot be changed now
+ALTER SYSTEM SET wal_sync_method = 'open_datasync';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_sync_method"
+ALTER SYSTEM RESET wal_sync_method;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_sync_method"
+SET wal_writer_delay = 50;  -- fail, requires reload
+ERROR:  parameter "wal_writer_delay" cannot be changed now
+RESET wal_writer_delay;  -- fail, requires reload
+ERROR:  parameter "wal_writer_delay" cannot be changed now
+ALTER SYSTEM SET wal_writer_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_delay"
+ALTER SYSTEM RESET wal_writer_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_delay"
+SET wal_writer_flush_after = 50;  -- fail, requires reload
+ERROR:  parameter "wal_writer_flush_after" cannot be changed now
+RESET wal_writer_flush_after;  -- fail, requires reload
+ERROR:  parameter "wal_writer_flush_after" cannot be changed now
+ALTER SYSTEM SET wal_writer_flush_after = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_flush_after"
+ALTER SYSTEM RESET wal_writer_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_writer_flush_after"
+-- PGC_SUSET / CLIENT_CONN_LOCALE
+SET lc_messages = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+RESET lc_messages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+ALTER SYSTEM SET lc_messages = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+ALTER SYSTEM RESET lc_messages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_messages"
+-- PGC_SUSET / CLIENT_CONN_OTHER
+SET dynamic_library_path = '$libdir';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+RESET dynamic_library_path;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+ALTER SYSTEM SET dynamic_library_path = '$libdir';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+ALTER SYSTEM RESET dynamic_library_path;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "dynamic_library_path"
+-- PGC_SUSET / CLIENT_CONN_PRELOAD
+SET session_preload_libraries = 'gssapi_krb5';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+RESET session_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+ALTER SYSTEM SET session_preload_libraries = 'gssapi_krb5';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+ALTER SYSTEM RESET session_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_preload_libraries"
+-- PGC_SUSET / CLIENT_CONN_STATEMENT
+SET session_replication_role = 'origin';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+RESET session_replication_role;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+ALTER SYSTEM SET session_replication_role = 'origin';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+ALTER SYSTEM RESET session_replication_role;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "session_replication_role"
+-- PGC_SUSET / COMPAT_OPTIONS_PREVIOUS
+SET lo_compat_privileges = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+RESET lo_compat_privileges;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+ALTER SYSTEM SET lo_compat_privileges = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+ALTER SYSTEM RESET lo_compat_privileges;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lo_compat_privileges"
+-- PGC_SUSET / DEVELOPER_OPTIONS
+SET allow_system_table_mods = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+RESET allow_system_table_mods;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+ALTER SYSTEM SET allow_system_table_mods = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+ALTER SYSTEM RESET allow_system_table_mods;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "allow_system_table_mods"
+SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+RESET backtrace_functions;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+ALTER SYSTEM SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+ALTER SYSTEM RESET backtrace_functions;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backtrace_functions"
+SET debug_discard_caches = 2;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+RESET debug_discard_caches;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+ALTER SYSTEM SET debug_discard_caches = 2;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+ALTER SYSTEM RESET debug_discard_caches;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_discard_caches"
+SET ignore_checksum_failure = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+RESET ignore_checksum_failure;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+ALTER SYSTEM SET ignore_checksum_failure = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+ALTER SYSTEM RESET ignore_checksum_failure;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "ignore_checksum_failure"
+SET jit_dump_bitcode = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+RESET jit_dump_bitcode;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+ALTER SYSTEM SET jit_dump_bitcode = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+ALTER SYSTEM RESET jit_dump_bitcode;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_dump_bitcode"
+SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+RESET wal_consistency_checking;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+ALTER SYSTEM SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+ALTER SYSTEM RESET wal_consistency_checking;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_consistency_checking"
+SET zero_damaged_pages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+RESET zero_damaged_pages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+ALTER SYSTEM SET zero_damaged_pages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+ALTER SYSTEM RESET zero_damaged_pages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "zero_damaged_pages"
+-- PGC_SUSET / LOCK_MANAGEMENT
+SET deadlock_timeout = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+RESET deadlock_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+ALTER SYSTEM SET deadlock_timeout = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+ALTER SYSTEM RESET deadlock_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "deadlock_timeout"
+-- PGC_SUSET / LOGGING_WHAT
+SET log_duration = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+RESET log_duration;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+ALTER SYSTEM SET log_duration = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+ALTER SYSTEM RESET log_duration;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_duration"
+SET log_error_verbosity = 'default';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+RESET log_error_verbosity;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+ALTER SYSTEM SET log_error_verbosity = 'default';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+ALTER SYSTEM RESET log_error_verbosity;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_error_verbosity"
+SET log_lock_waits = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+RESET log_lock_waits;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+ALTER SYSTEM SET log_lock_waits = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+ALTER SYSTEM RESET log_lock_waits;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_lock_waits"
+SET log_parameter_max_length = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+RESET log_parameter_max_length;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+ALTER SYSTEM SET log_parameter_max_length = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+ALTER SYSTEM RESET log_parameter_max_length;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length"
+SET log_replication_commands = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+RESET log_replication_commands;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+ALTER SYSTEM SET log_replication_commands = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+ALTER SYSTEM RESET log_replication_commands;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_replication_commands"
+SET log_statement = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+RESET log_statement;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+ALTER SYSTEM SET log_statement = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+ALTER SYSTEM RESET log_statement;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement"
+SET log_temp_files = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+RESET log_temp_files;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+ALTER SYSTEM SET log_temp_files = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+ALTER SYSTEM RESET log_temp_files;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_temp_files"
+-- PGC_SUSET / LOGGING_WHEN
+SET log_min_duration_sample = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+RESET log_min_duration_sample;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+ALTER SYSTEM SET log_min_duration_sample = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+ALTER SYSTEM RESET log_min_duration_sample;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_sample"
+SET log_min_duration_statement = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+RESET log_min_duration_statement;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+ALTER SYSTEM SET log_min_duration_statement = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+ALTER SYSTEM RESET log_min_duration_statement;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_duration_statement"
+SET log_min_error_statement = 'error';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+RESET log_min_error_statement;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+ALTER SYSTEM SET log_min_error_statement = 'error';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+ALTER SYSTEM RESET log_min_error_statement;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_error_statement"
+SET log_min_messages = 'warning';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+RESET log_min_messages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+ALTER SYSTEM SET log_min_messages = 'warning';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+ALTER SYSTEM RESET log_min_messages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_min_messages"
+SET log_statement_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+RESET log_statement_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+ALTER SYSTEM SET log_statement_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+ALTER SYSTEM RESET log_statement_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_sample_rate"
+SET log_transaction_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+RESET log_transaction_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+ALTER SYSTEM SET log_transaction_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+ALTER SYSTEM RESET log_transaction_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_transaction_sample_rate"
+-- PGC_SUSET / PROCESS_TITLE
+SET update_process_title = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+RESET update_process_title;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+ALTER SYSTEM SET update_process_title = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+ALTER SYSTEM RESET update_process_title;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "update_process_title"
+-- PGC_SUSET / RESOURCES_DISK
+SET temp_file_limit = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+RESET temp_file_limit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+ALTER SYSTEM SET temp_file_limit = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+ALTER SYSTEM RESET temp_file_limit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_file_limit"
+-- PGC_SUSET / RESOURCES_MEM
+SET max_stack_depth = 3890;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+RESET max_stack_depth;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+ALTER SYSTEM SET max_stack_depth = 3890;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+ALTER SYSTEM RESET max_stack_depth;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_stack_depth"
+-- PGC_SUSET / STATS_COLLECTOR
+SET track_activities = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+RESET track_activities;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+ALTER SYSTEM SET track_activities = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+ALTER SYSTEM RESET track_activities;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_activities"
+SET track_counts = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+RESET track_counts;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+ALTER SYSTEM SET track_counts = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+ALTER SYSTEM RESET track_counts;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_counts"
+SET track_functions = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+RESET track_functions;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+ALTER SYSTEM SET track_functions = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+ALTER SYSTEM RESET track_functions;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_functions"
+SET track_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+RESET track_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+ALTER SYSTEM SET track_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+ALTER SYSTEM RESET track_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_io_timing"
+SET track_wal_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+RESET track_wal_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+ALTER SYSTEM SET track_wal_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+ALTER SYSTEM RESET track_wal_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "track_wal_io_timing"
+-- PGC_SUSET / STATS_MONITORING
+SET compute_query_id = 'auto';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+RESET compute_query_id;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+ALTER SYSTEM SET compute_query_id = 'auto';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+ALTER SYSTEM RESET compute_query_id;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "compute_query_id"
+SET log_executor_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+RESET log_executor_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+ALTER SYSTEM SET log_executor_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+ALTER SYSTEM RESET log_executor_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_executor_stats"
+SET log_parser_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+RESET log_parser_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+ALTER SYSTEM SET log_parser_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+ALTER SYSTEM RESET log_parser_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parser_stats"
+SET log_planner_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+RESET log_planner_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+ALTER SYSTEM SET log_planner_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+ALTER SYSTEM RESET log_planner_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_planner_stats"
+SET log_statement_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+RESET log_statement_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+ALTER SYSTEM SET log_statement_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+ALTER SYSTEM RESET log_statement_stats;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_statement_stats"
+-- PGC_SUSET / WAL_SETTINGS
+SET commit_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+RESET commit_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+ALTER SYSTEM SET commit_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+ALTER SYSTEM RESET commit_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_delay"
+SET wal_compression = 'pglz';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+RESET wal_compression;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+ALTER SYSTEM SET wal_compression = 'pglz';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+ALTER SYSTEM RESET wal_compression;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_compression"
+SET wal_init_zero = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+RESET wal_init_zero;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+ALTER SYSTEM SET wal_init_zero = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+ALTER SYSTEM RESET wal_init_zero;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_init_zero"
+SET wal_recycle = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+RESET wal_recycle;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+ALTER SYSTEM SET wal_recycle = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+ALTER SYSTEM RESET wal_recycle;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_recycle"
+-- PGC_SU_BACKEND / DEVELOPER_OPTIONS
+SET jit_debugging_support = OFF;  -- fail, cannot be set after connection start
+ERROR:  parameter "jit_debugging_support" cannot be set after connection start
+RESET jit_debugging_support;  -- fail, cannot be set after connection start
+ERROR:  parameter "jit_debugging_support" cannot be set after connection start
+ALTER SYSTEM SET jit_debugging_support = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_debugging_support"
+ALTER SYSTEM RESET jit_debugging_support;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_debugging_support"
+SET jit_profiling_support = OFF;  -- fail, cannot be set after connection start
+ERROR:  parameter "jit_profiling_support" cannot be set after connection start
+RESET jit_profiling_support;  -- fail, cannot be set after connection start
+ERROR:  parameter "jit_profiling_support" cannot be set after connection start
+ALTER SYSTEM SET jit_profiling_support = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_profiling_support"
+ALTER SYSTEM RESET jit_profiling_support;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_profiling_support"
+-- PGC_SU_BACKEND / LOGGING_WHAT
+SET log_connections = OFF;  -- fail, cannot be set after connection start
+ERROR:  parameter "log_connections" cannot be set after connection start
+RESET log_connections;  -- fail, cannot be set after connection start
+ERROR:  parameter "log_connections" cannot be set after connection start
+ALTER SYSTEM SET log_connections = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_connections"
+ALTER SYSTEM RESET log_connections;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_connections"
+SET log_disconnections = OFF;  -- fail, cannot be set after connection start
+ERROR:  parameter "log_disconnections" cannot be set after connection start
+RESET log_disconnections;  -- fail, cannot be set after connection start
+ERROR:  parameter "log_disconnections" cannot be set after connection start
+ALTER SYSTEM SET log_disconnections = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_disconnections"
+ALTER SYSTEM RESET log_disconnections;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_disconnections"
+-- PGC_USERSET / CLIENT_CONN_LOCALE
+SET DateStyle = 'ISO, MDY';  -- ok
+RESET DateStyle;  -- ok
+ALTER SYSTEM SET DateStyle = 'ISO, MDY';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "datestyle"
+ALTER SYSTEM RESET DateStyle;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "datestyle"
+SET IntervalStyle = 'postgres';  -- ok
+RESET IntervalStyle;  -- ok
+ALTER SYSTEM SET IntervalStyle = 'postgres';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "intervalstyle"
+ALTER SYSTEM RESET IntervalStyle;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "intervalstyle"
+SET TimeZone = 'Europe/Helsinki';  -- ok
+RESET TimeZone;  -- ok
+ALTER SYSTEM SET TimeZone = 'Europe/Helsinki';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone"
+ALTER SYSTEM RESET TimeZone;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone"
+SET client_encoding = 'UTF8';  -- ok
+RESET client_encoding;  -- ok
+ALTER SYSTEM SET client_encoding = 'UTF8';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_encoding"
+ALTER SYSTEM RESET client_encoding;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_encoding"
+SET default_text_search_config = 'pg_catalog.english';  -- ok
+RESET default_text_search_config;  -- ok
+ALTER SYSTEM SET default_text_search_config = 'pg_catalog.english';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_text_search_config"
+ALTER SYSTEM RESET default_text_search_config;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_text_search_config"
+SET extra_float_digits = -6;  -- ok
+RESET extra_float_digits;  -- ok
+ALTER SYSTEM SET extra_float_digits = -6;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "extra_float_digits"
+ALTER SYSTEM RESET extra_float_digits;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "extra_float_digits"
+SET lc_monetary = 'en_US.UTF-8';  -- ok
+RESET lc_monetary;  -- ok
+ALTER SYSTEM SET lc_monetary = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_monetary"
+ALTER SYSTEM RESET lc_monetary;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_monetary"
+SET lc_numeric = 'en_US.UTF-8';  -- ok
+RESET lc_numeric;  -- ok
+ALTER SYSTEM SET lc_numeric = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_numeric"
+ALTER SYSTEM RESET lc_numeric;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_numeric"
+SET lc_time = 'en_US.UTF-8';  -- ok
+RESET lc_time;  -- ok
+ALTER SYSTEM SET lc_time = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_time"
+ALTER SYSTEM RESET lc_time;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lc_time"
+SET timezone_abbreviations = 'Default';  -- ok
+RESET timezone_abbreviations;  -- ok
+ALTER SYSTEM SET timezone_abbreviations = 'Default';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone_abbreviations"
+ALTER SYSTEM RESET timezone_abbreviations;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "timezone_abbreviations"
+-- PGC_USERSET / CLIENT_CONN_OTHER
+SET gin_fuzzy_search_limit = 50;  -- ok
+RESET gin_fuzzy_search_limit;  -- ok
+ALTER SYSTEM SET gin_fuzzy_search_limit = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_fuzzy_search_limit"
+ALTER SYSTEM RESET gin_fuzzy_search_limit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_fuzzy_search_limit"
+-- PGC_USERSET / CLIENT_CONN_PRELOAD
+SET local_preload_libraries = 'gssapi_krb5';  -- ok
+RESET local_preload_libraries;  -- ok
+ALTER SYSTEM SET local_preload_libraries = 'gssapi_krb5';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "local_preload_libraries"
+ALTER SYSTEM RESET local_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "local_preload_libraries"
+-- PGC_USERSET / CLIENT_CONN_STATEMENT
+SET bytea_output = 'hex';  -- ok
+RESET bytea_output;  -- ok
+ALTER SYSTEM SET bytea_output = 'hex';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bytea_output"
+ALTER SYSTEM RESET bytea_output;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "bytea_output"
+SET check_function_bodies = OFF;  -- ok
+RESET check_function_bodies;  -- ok
+ALTER SYSTEM SET check_function_bodies = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "check_function_bodies"
+ALTER SYSTEM RESET check_function_bodies;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "check_function_bodies"
+SET client_min_messages = 'notice';  -- ok
+RESET client_min_messages;  -- ok
+ALTER SYSTEM SET client_min_messages = 'notice';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_min_messages"
+ALTER SYSTEM RESET client_min_messages;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_min_messages"
+SET default_table_access_method = 'heap';  -- ok
+RESET default_table_access_method;  -- ok
+ALTER SYSTEM SET default_table_access_method = 'heap';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_table_access_method"
+ALTER SYSTEM RESET default_table_access_method;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_table_access_method"
+SET default_toast_compression = 'pglz';  -- ok
+RESET default_toast_compression;  -- ok
+ALTER SYSTEM SET default_toast_compression = 'pglz';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_toast_compression"
+ALTER SYSTEM RESET default_toast_compression;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_toast_compression"
+SET default_transaction_deferrable = OFF;  -- ok
+RESET default_transaction_deferrable;  -- ok
+ALTER SYSTEM SET default_transaction_deferrable = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_deferrable"
+ALTER SYSTEM RESET default_transaction_deferrable;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_deferrable"
+SET default_transaction_isolation = 'read committed';  -- ok
+RESET default_transaction_isolation;  -- ok
+ALTER SYSTEM SET default_transaction_isolation = 'read committed';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_isolation"
+ALTER SYSTEM RESET default_transaction_isolation;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_isolation"
+SET default_transaction_read_only = OFF;  -- ok
+RESET default_transaction_read_only;  -- ok
+ALTER SYSTEM SET default_transaction_read_only = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_read_only"
+ALTER SYSTEM RESET default_transaction_read_only;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_transaction_read_only"
+SET gin_pending_list_limit = 1073741855;  -- ok
+RESET gin_pending_list_limit;  -- ok
+ALTER SYSTEM SET gin_pending_list_limit = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_pending_list_limit"
+ALTER SYSTEM RESET gin_pending_list_limit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "gin_pending_list_limit"
+SET idle_in_transaction_session_timeout = 50;  -- ok
+RESET idle_in_transaction_session_timeout;  -- ok
+ALTER SYSTEM SET idle_in_transaction_session_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_in_transaction_session_timeout"
+ALTER SYSTEM RESET idle_in_transaction_session_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_in_transaction_session_timeout"
+SET idle_session_timeout = 50;  -- ok
+RESET idle_session_timeout;  -- ok
+ALTER SYSTEM SET idle_session_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_session_timeout"
+ALTER SYSTEM RESET idle_session_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "idle_session_timeout"
+SET lock_timeout = 50;  -- ok
+RESET lock_timeout;  -- ok
+ALTER SYSTEM SET lock_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lock_timeout"
+ALTER SYSTEM RESET lock_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "lock_timeout"
+SET row_security = OFF;  -- ok
+RESET row_security;  -- ok
+ALTER SYSTEM SET row_security = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "row_security"
+ALTER SYSTEM RESET row_security;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "row_security"
+SET search_path = '"$user", public';  -- ok
+RESET search_path;  -- ok
+ALTER SYSTEM SET search_path = '"$user", public';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "search_path"
+ALTER SYSTEM RESET search_path;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "search_path"
+SET statement_timeout = 5250;  -- ok
+RESET statement_timeout;  -- ok
+ALTER SYSTEM SET statement_timeout = 5250;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "statement_timeout"
+ALTER SYSTEM RESET statement_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "statement_timeout"
+SET transaction_deferrable = OFF;  -- ok
+RESET transaction_deferrable;  -- ok
+ALTER SYSTEM SET transaction_deferrable = OFF;  -- fail, cannot be changed
+ERROR:  parameter "transaction_deferrable" cannot be changed
+ALTER SYSTEM RESET transaction_deferrable;  -- fail, cannot be changed
+ERROR:  parameter "transaction_deferrable" cannot be changed
+SET transaction_read_only = OFF;  -- ok
+RESET transaction_read_only;  -- ok
+ALTER SYSTEM SET transaction_read_only = OFF;  -- fail, cannot be changed
+ERROR:  parameter "transaction_read_only" cannot be changed
+ALTER SYSTEM RESET transaction_read_only;  -- fail, cannot be changed
+ERROR:  parameter "transaction_read_only" cannot be changed
+SET vacuum_failsafe_age = 50;  -- ok
+RESET vacuum_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_failsafe_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_failsafe_age"
+ALTER SYSTEM RESET vacuum_failsafe_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_failsafe_age"
+SET vacuum_freeze_min_age = 50;  -- ok
+RESET vacuum_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_min_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_min_age"
+ALTER SYSTEM RESET vacuum_freeze_min_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_min_age"
+SET vacuum_freeze_table_age = 50;  -- ok
+RESET vacuum_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_table_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_table_age"
+ALTER SYSTEM RESET vacuum_freeze_table_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_freeze_table_age"
+SET vacuum_multixact_failsafe_age = 50;  -- ok
+RESET vacuum_multixact_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_failsafe_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_failsafe_age"
+ALTER SYSTEM RESET vacuum_multixact_failsafe_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_failsafe_age"
+SET vacuum_multixact_freeze_min_age = 50;  -- ok
+RESET vacuum_multixact_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_min_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_min_age"
+ALTER SYSTEM RESET vacuum_multixact_freeze_min_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_min_age"
+SET vacuum_multixact_freeze_table_age = 50;  -- ok
+RESET vacuum_multixact_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_table_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_table_age"
+ALTER SYSTEM RESET vacuum_multixact_freeze_table_age;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_multixact_freeze_table_age"
+SET xmlbinary = 'base64';  -- ok
+RESET xmlbinary;  -- ok
+ALTER SYSTEM SET xmlbinary = 'base64';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmlbinary"
+ALTER SYSTEM RESET xmlbinary;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmlbinary"
+SET xmloption = 'content';  -- ok
+RESET xmloption;  -- ok
+ALTER SYSTEM SET xmloption = 'content';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmloption"
+ALTER SYSTEM RESET xmloption;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "xmloption"
+-- PGC_USERSET / COMPAT_OPTIONS_PREVIOUS
+SET array_nulls = OFF;  -- ok
+RESET array_nulls;  -- ok
+ALTER SYSTEM SET array_nulls = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "array_nulls"
+ALTER SYSTEM RESET array_nulls;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "array_nulls"
+SET escape_string_warning = OFF;  -- ok
+RESET escape_string_warning;  -- ok
+ALTER SYSTEM SET escape_string_warning = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "escape_string_warning"
+ALTER SYSTEM RESET escape_string_warning;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "escape_string_warning"
+SET quote_all_identifiers = OFF;  -- ok
+RESET quote_all_identifiers;  -- ok
+ALTER SYSTEM SET quote_all_identifiers = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "quote_all_identifiers"
+ALTER SYSTEM RESET quote_all_identifiers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "quote_all_identifiers"
+SET standard_conforming_strings = OFF;  -- ok
+RESET standard_conforming_strings;  -- ok
+ALTER SYSTEM SET standard_conforming_strings = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "standard_conforming_strings"
+ALTER SYSTEM RESET standard_conforming_strings;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "standard_conforming_strings"
+SET synchronize_seqscans = OFF;  -- ok
+RESET synchronize_seqscans;  -- ok
+ALTER SYSTEM SET synchronize_seqscans = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronize_seqscans"
+ALTER SYSTEM RESET synchronize_seqscans;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronize_seqscans"
+-- PGC_USERSET / CONN_AUTH_AUTH
+SET password_encryption = 'scram-sha-256';  -- ok
+RESET password_encryption;  -- ok
+ALTER SYSTEM SET password_encryption = 'scram-sha-256';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "password_encryption"
+ALTER SYSTEM RESET password_encryption;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "password_encryption"
+-- PGC_USERSET / CONN_AUTH_SETTINGS
+SET client_connection_check_interval = 0;  -- ok
+RESET client_connection_check_interval;  -- ok
+ALTER SYSTEM SET client_connection_check_interval = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_connection_check_interval"
+ALTER SYSTEM RESET client_connection_check_interval;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "client_connection_check_interval"
+SET tcp_keepalives_count = 50;  -- ok
+RESET tcp_keepalives_count;  -- ok
+ALTER SYSTEM SET tcp_keepalives_count = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_count"
+ALTER SYSTEM RESET tcp_keepalives_count;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_count"
+SET tcp_keepalives_idle = 50;  -- ok
+RESET tcp_keepalives_idle;  -- ok
+ALTER SYSTEM SET tcp_keepalives_idle = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_idle"
+ALTER SYSTEM RESET tcp_keepalives_idle;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_idle"
+SET tcp_keepalives_interval = 50;  -- ok
+RESET tcp_keepalives_interval;  -- ok
+ALTER SYSTEM SET tcp_keepalives_interval = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_interval"
+ALTER SYSTEM RESET tcp_keepalives_interval;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_keepalives_interval"
+SET tcp_user_timeout = 50;  -- ok
+RESET tcp_user_timeout;  -- ok
+ALTER SYSTEM SET tcp_user_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_user_timeout"
+ALTER SYSTEM RESET tcp_user_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "tcp_user_timeout"
+-- PGC_USERSET / CONN_AUTH_SSL
+SET ssl_renegotiation_limit = 0;  -- ok
+RESET ssl_renegotiation_limit;  -- ok
+ALTER SYSTEM SET ssl_renegotiation_limit = 0;  -- fail, cannot be changed
+ERROR:  parameter "ssl_renegotiation_limit" cannot be changed
+ALTER SYSTEM RESET ssl_renegotiation_limit;  -- fail, cannot be changed
+ERROR:  parameter "ssl_renegotiation_limit" cannot be changed
+-- PGC_USERSET / DEVELOPER_OPTIONS
+SET force_parallel_mode = 'off';  -- ok
+RESET force_parallel_mode;  -- ok
+ALTER SYSTEM SET force_parallel_mode = 'off';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "force_parallel_mode"
+ALTER SYSTEM RESET force_parallel_mode;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "force_parallel_mode"
+SET jit_expressions = OFF;  -- ok
+RESET jit_expressions;  -- ok
+ALTER SYSTEM SET jit_expressions = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_expressions"
+ALTER SYSTEM RESET jit_expressions;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_expressions"
+SET jit_tuple_deforming = OFF;  -- ok
+RESET jit_tuple_deforming;  -- ok
+ALTER SYSTEM SET jit_tuple_deforming = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_tuple_deforming"
+ALTER SYSTEM RESET jit_tuple_deforming;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_tuple_deforming"
+SET trace_notify = OFF;  -- ok
+RESET trace_notify;  -- ok
+ALTER SYSTEM SET trace_notify = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_notify"
+ALTER SYSTEM RESET trace_notify;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_notify"
+SET trace_sort = OFF;  -- ok
+RESET trace_sort;  -- ok
+ALTER SYSTEM SET trace_sort = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_sort"
+ALTER SYSTEM RESET trace_sort;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "trace_sort"
+-- PGC_USERSET / ERROR_HANDLING_OPTIONS
+SET exit_on_error = OFF;  -- ok
+RESET exit_on_error;  -- ok
+ALTER SYSTEM SET exit_on_error = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "exit_on_error"
+ALTER SYSTEM RESET exit_on_error;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "exit_on_error"
+-- PGC_USERSET / LOGGING_WHAT
+SET application_name = 'psql';  -- ok
+RESET application_name;  -- ok
+ALTER SYSTEM SET application_name = 'psql';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "application_name"
+ALTER SYSTEM RESET application_name;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "application_name"
+SET debug_pretty_print = OFF;  -- ok
+RESET debug_pretty_print;  -- ok
+ALTER SYSTEM SET debug_pretty_print = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_pretty_print"
+ALTER SYSTEM RESET debug_pretty_print;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_pretty_print"
+SET debug_print_parse = OFF;  -- ok
+RESET debug_print_parse;  -- ok
+ALTER SYSTEM SET debug_print_parse = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_parse"
+ALTER SYSTEM RESET debug_print_parse;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_parse"
+SET debug_print_plan = OFF;  -- ok
+RESET debug_print_plan;  -- ok
+ALTER SYSTEM SET debug_print_plan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_plan"
+ALTER SYSTEM RESET debug_print_plan;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_plan"
+SET debug_print_rewritten = OFF;  -- ok
+RESET debug_print_rewritten;  -- ok
+ALTER SYSTEM SET debug_print_rewritten = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_rewritten"
+ALTER SYSTEM RESET debug_print_rewritten;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "debug_print_rewritten"
+SET log_parameter_max_length_on_error = 50;  -- ok
+RESET log_parameter_max_length_on_error;  -- ok
+ALTER SYSTEM SET log_parameter_max_length_on_error = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length_on_error"
+ALTER SYSTEM RESET log_parameter_max_length_on_error;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "log_parameter_max_length_on_error"
+-- PGC_USERSET / QUERY_TUNING_COST
+SET cpu_index_tuple_cost = 50;  -- ok
+RESET cpu_index_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_index_tuple_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_index_tuple_cost"
+ALTER SYSTEM RESET cpu_index_tuple_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_index_tuple_cost"
+SET cpu_operator_cost = 50;  -- ok
+RESET cpu_operator_cost;  -- ok
+ALTER SYSTEM SET cpu_operator_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_operator_cost"
+ALTER SYSTEM RESET cpu_operator_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_operator_cost"
+SET cpu_tuple_cost = 50;  -- ok
+RESET cpu_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_tuple_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_tuple_cost"
+ALTER SYSTEM RESET cpu_tuple_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cpu_tuple_cost"
+SET effective_cache_size = 1073741824;  -- ok
+RESET effective_cache_size;  -- ok
+ALTER SYSTEM SET effective_cache_size = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_cache_size"
+ALTER SYSTEM RESET effective_cache_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_cache_size"
+SET jit_above_cost = 50;  -- ok
+RESET jit_above_cost;  -- ok
+ALTER SYSTEM SET jit_above_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_above_cost"
+ALTER SYSTEM RESET jit_above_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_above_cost"
+SET jit_inline_above_cost = 50;  -- ok
+RESET jit_inline_above_cost;  -- ok
+ALTER SYSTEM SET jit_inline_above_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_inline_above_cost"
+ALTER SYSTEM RESET jit_inline_above_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_inline_above_cost"
+SET jit_optimize_above_cost = 50;  -- ok
+RESET jit_optimize_above_cost;  -- ok
+ALTER SYSTEM SET jit_optimize_above_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_optimize_above_cost"
+ALTER SYSTEM RESET jit_optimize_above_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit_optimize_above_cost"
+SET min_parallel_index_scan_size = 50;  -- ok
+RESET min_parallel_index_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_index_scan_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_index_scan_size"
+ALTER SYSTEM RESET min_parallel_index_scan_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_index_scan_size"
+SET min_parallel_table_scan_size = 50;  -- ok
+RESET min_parallel_table_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_table_scan_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_table_scan_size"
+ALTER SYSTEM RESET min_parallel_table_scan_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "min_parallel_table_scan_size"
+SET parallel_setup_cost = 50;  -- ok
+RESET parallel_setup_cost;  -- ok
+ALTER SYSTEM SET parallel_setup_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_setup_cost"
+ALTER SYSTEM RESET parallel_setup_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_setup_cost"
+SET parallel_tuple_cost = 50;  -- ok
+RESET parallel_tuple_cost;  -- ok
+ALTER SYSTEM SET parallel_tuple_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_tuple_cost"
+ALTER SYSTEM RESET parallel_tuple_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_tuple_cost"
+SET random_page_cost = 50;  -- ok
+RESET random_page_cost;  -- ok
+ALTER SYSTEM SET random_page_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "random_page_cost"
+ALTER SYSTEM RESET random_page_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "random_page_cost"
+SET seq_page_cost = 50;  -- ok
+RESET seq_page_cost;  -- ok
+ALTER SYSTEM SET seq_page_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "seq_page_cost"
+ALTER SYSTEM RESET seq_page_cost;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "seq_page_cost"
+-- PGC_USERSET / QUERY_TUNING_GEQO
+SET geqo = OFF;  -- ok
+RESET geqo;  -- ok
+ALTER SYSTEM SET geqo = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo"
+ALTER SYSTEM RESET geqo;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo"
+SET geqo_effort = 5;  -- ok
+RESET geqo_effort;  -- ok
+ALTER SYSTEM SET geqo_effort = 5;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_effort"
+ALTER SYSTEM RESET geqo_effort;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_effort"
+SET geqo_generations = 50;  -- ok
+RESET geqo_generations;  -- ok
+ALTER SYSTEM SET geqo_generations = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_generations"
+ALTER SYSTEM RESET geqo_generations;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_generations"
+SET geqo_pool_size = 50;  -- ok
+RESET geqo_pool_size;  -- ok
+ALTER SYSTEM SET geqo_pool_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_pool_size"
+ALTER SYSTEM RESET geqo_pool_size;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_pool_size"
+SET geqo_seed = 0;  -- ok
+RESET geqo_seed;  -- ok
+ALTER SYSTEM SET geqo_seed = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_seed"
+ALTER SYSTEM RESET geqo_seed;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_seed"
+SET geqo_selection_bias = 2;  -- ok
+RESET geqo_selection_bias;  -- ok
+ALTER SYSTEM SET geqo_selection_bias = 2;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_selection_bias"
+ALTER SYSTEM RESET geqo_selection_bias;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_selection_bias"
+SET geqo_threshold = 1073741824;  -- ok
+RESET geqo_threshold;  -- ok
+ALTER SYSTEM SET geqo_threshold = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_threshold"
+ALTER SYSTEM RESET geqo_threshold;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "geqo_threshold"
+-- PGC_USERSET / QUERY_TUNING_METHOD
+SET enable_async_append = OFF;  -- ok
+RESET enable_async_append;  -- ok
+ALTER SYSTEM SET enable_async_append = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_async_append"
+ALTER SYSTEM RESET enable_async_append;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_async_append"
+SET enable_bitmapscan = OFF;  -- ok
+RESET enable_bitmapscan;  -- ok
+ALTER SYSTEM SET enable_bitmapscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_bitmapscan"
+ALTER SYSTEM RESET enable_bitmapscan;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_bitmapscan"
+SET enable_gathermerge = OFF;  -- ok
+RESET enable_gathermerge;  -- ok
+ALTER SYSTEM SET enable_gathermerge = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_gathermerge"
+ALTER SYSTEM RESET enable_gathermerge;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_gathermerge"
+SET enable_hashagg = OFF;  -- ok
+RESET enable_hashagg;  -- ok
+ALTER SYSTEM SET enable_hashagg = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashagg"
+ALTER SYSTEM RESET enable_hashagg;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashagg"
+SET enable_hashjoin = OFF;  -- ok
+RESET enable_hashjoin;  -- ok
+ALTER SYSTEM SET enable_hashjoin = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashjoin"
+ALTER SYSTEM RESET enable_hashjoin;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_hashjoin"
+SET enable_incremental_sort = OFF;  -- ok
+RESET enable_incremental_sort;  -- ok
+ALTER SYSTEM SET enable_incremental_sort = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_incremental_sort"
+ALTER SYSTEM RESET enable_incremental_sort;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_incremental_sort"
+SET enable_indexonlyscan = OFF;  -- ok
+RESET enable_indexonlyscan;  -- ok
+ALTER SYSTEM SET enable_indexonlyscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexonlyscan"
+ALTER SYSTEM RESET enable_indexonlyscan;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexonlyscan"
+SET enable_indexscan = OFF;  -- ok
+RESET enable_indexscan;  -- ok
+ALTER SYSTEM SET enable_indexscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexscan"
+ALTER SYSTEM RESET enable_indexscan;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_indexscan"
+SET enable_material = OFF;  -- ok
+RESET enable_material;  -- ok
+ALTER SYSTEM SET enable_material = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_material"
+ALTER SYSTEM RESET enable_material;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_material"
+SET enable_memoize = OFF;  -- ok
+RESET enable_memoize;  -- ok
+ALTER SYSTEM SET enable_memoize = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_memoize"
+ALTER SYSTEM RESET enable_memoize;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_memoize"
+SET enable_mergejoin = OFF;  -- ok
+RESET enable_mergejoin;  -- ok
+ALTER SYSTEM SET enable_mergejoin = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_mergejoin"
+ALTER SYSTEM RESET enable_mergejoin;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_mergejoin"
+SET enable_nestloop = OFF;  -- ok
+RESET enable_nestloop;  -- ok
+ALTER SYSTEM SET enable_nestloop = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_nestloop"
+ALTER SYSTEM RESET enable_nestloop;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_nestloop"
+SET enable_parallel_append = OFF;  -- ok
+RESET enable_parallel_append;  -- ok
+ALTER SYSTEM SET enable_parallel_append = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_append"
+ALTER SYSTEM RESET enable_parallel_append;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_append"
+SET enable_parallel_hash = OFF;  -- ok
+RESET enable_parallel_hash;  -- ok
+ALTER SYSTEM SET enable_parallel_hash = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_hash"
+ALTER SYSTEM RESET enable_parallel_hash;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_parallel_hash"
+SET enable_partition_pruning = OFF;  -- ok
+RESET enable_partition_pruning;  -- ok
+ALTER SYSTEM SET enable_partition_pruning = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partition_pruning"
+ALTER SYSTEM RESET enable_partition_pruning;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partition_pruning"
+SET enable_partitionwise_aggregate = OFF;  -- ok
+RESET enable_partitionwise_aggregate;  -- ok
+ALTER SYSTEM SET enable_partitionwise_aggregate = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_aggregate"
+ALTER SYSTEM RESET enable_partitionwise_aggregate;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_aggregate"
+SET enable_partitionwise_join = OFF;  -- ok
+RESET enable_partitionwise_join;  -- ok
+ALTER SYSTEM SET enable_partitionwise_join = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_join"
+ALTER SYSTEM RESET enable_partitionwise_join;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_partitionwise_join"
+SET enable_seqscan = OFF;  -- ok
+RESET enable_seqscan;  -- ok
+ALTER SYSTEM SET enable_seqscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_seqscan"
+ALTER SYSTEM RESET enable_seqscan;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_seqscan"
+SET enable_sort = OFF;  -- ok
+RESET enable_sort;  -- ok
+ALTER SYSTEM SET enable_sort = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_sort"
+ALTER SYSTEM RESET enable_sort;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_sort"
+SET enable_tidscan = OFF;  -- ok
+RESET enable_tidscan;  -- ok
+ALTER SYSTEM SET enable_tidscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_tidscan"
+ALTER SYSTEM RESET enable_tidscan;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "enable_tidscan"
+-- PGC_USERSET / QUERY_TUNING_OTHER
+SET constraint_exclusion = 'partition';  -- ok
+RESET constraint_exclusion;  -- ok
+ALTER SYSTEM SET constraint_exclusion = 'partition';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "constraint_exclusion"
+ALTER SYSTEM RESET constraint_exclusion;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "constraint_exclusion"
+SET cursor_tuple_fraction = 0;  -- ok
+RESET cursor_tuple_fraction;  -- ok
+ALTER SYSTEM SET cursor_tuple_fraction = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cursor_tuple_fraction"
+ALTER SYSTEM RESET cursor_tuple_fraction;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "cursor_tuple_fraction"
+SET default_statistics_target = 5000;  -- ok
+RESET default_statistics_target;  -- ok
+ALTER SYSTEM SET default_statistics_target = 5000;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_statistics_target"
+ALTER SYSTEM RESET default_statistics_target;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "default_statistics_target"
+SET from_collapse_limit = 1073741824;  -- ok
+RESET from_collapse_limit;  -- ok
+ALTER SYSTEM SET from_collapse_limit = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "from_collapse_limit"
+ALTER SYSTEM RESET from_collapse_limit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "from_collapse_limit"
+SET jit = OFF;  -- ok
+RESET jit;  -- ok
+ALTER SYSTEM SET jit = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit"
+ALTER SYSTEM RESET jit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "jit"
+SET join_collapse_limit = 1073741824;  -- ok
+RESET join_collapse_limit;  -- ok
+ALTER SYSTEM SET join_collapse_limit = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "join_collapse_limit"
+ALTER SYSTEM RESET join_collapse_limit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "join_collapse_limit"
+SET plan_cache_mode = 'force_generic_plan';  -- ok
+RESET plan_cache_mode;  -- ok
+ALTER SYSTEM SET plan_cache_mode = 'force_generic_plan';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "plan_cache_mode"
+ALTER SYSTEM RESET plan_cache_mode;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "plan_cache_mode"
+-- PGC_USERSET / REPLICATION_SENDING
+SET wal_sender_timeout = 50;  -- ok
+RESET wal_sender_timeout;  -- ok
+ALTER SYSTEM SET wal_sender_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_sender_timeout"
+ALTER SYSTEM RESET wal_sender_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_sender_timeout"
+-- PGC_USERSET / RESOURCES_ASYNCHRONOUS
+SET backend_flush_after = 128;  -- ok
+RESET backend_flush_after;  -- ok
+ALTER SYSTEM SET backend_flush_after = 128;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backend_flush_after"
+ALTER SYSTEM RESET backend_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "backend_flush_after"
+SET effective_io_concurrency = 0;  -- ok
+RESET effective_io_concurrency;  -- ok
+ALTER SYSTEM SET effective_io_concurrency = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_io_concurrency"
+ALTER SYSTEM RESET effective_io_concurrency;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "effective_io_concurrency"
+SET maintenance_io_concurrency = 0;  -- ok
+RESET maintenance_io_concurrency;  -- ok
+ALTER SYSTEM SET maintenance_io_concurrency = 0;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_io_concurrency"
+ALTER SYSTEM RESET maintenance_io_concurrency;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_io_concurrency"
+SET max_parallel_maintenance_workers = 50;  -- ok
+RESET max_parallel_maintenance_workers;  -- ok
+ALTER SYSTEM SET max_parallel_maintenance_workers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_maintenance_workers"
+ALTER SYSTEM RESET max_parallel_maintenance_workers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_maintenance_workers"
+SET max_parallel_workers = 50;  -- ok
+RESET max_parallel_workers;  -- ok
+ALTER SYSTEM SET max_parallel_workers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers"
+ALTER SYSTEM RESET max_parallel_workers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers"
+SET max_parallel_workers_per_gather = 50;  -- ok
+RESET max_parallel_workers_per_gather;  -- ok
+ALTER SYSTEM SET max_parallel_workers_per_gather = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers_per_gather"
+ALTER SYSTEM RESET max_parallel_workers_per_gather;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "max_parallel_workers_per_gather"
+SET parallel_leader_participation = OFF;  -- ok
+RESET parallel_leader_participation;  -- ok
+ALTER SYSTEM SET parallel_leader_participation = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_leader_participation"
+ALTER SYSTEM RESET parallel_leader_participation;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "parallel_leader_participation"
+-- PGC_USERSET / RESOURCES_MEM
+SET hash_mem_multiplier = 500;  -- ok
+RESET hash_mem_multiplier;  -- ok
+ALTER SYSTEM SET hash_mem_multiplier = 500;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hash_mem_multiplier"
+ALTER SYSTEM RESET hash_mem_multiplier;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "hash_mem_multiplier"
+SET logical_decoding_work_mem = 1073741855;  -- ok
+RESET logical_decoding_work_mem;  -- ok
+ALTER SYSTEM SET logical_decoding_work_mem = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logical_decoding_work_mem"
+ALTER SYSTEM RESET logical_decoding_work_mem;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "logical_decoding_work_mem"
+SET maintenance_work_mem = 1073742335;  -- ok
+RESET maintenance_work_mem;  -- ok
+ALTER SYSTEM SET maintenance_work_mem = 1073742335;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_work_mem"
+ALTER SYSTEM RESET maintenance_work_mem;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "maintenance_work_mem"
+SET temp_buffers = 536870961;  -- ok
+RESET temp_buffers;  -- ok
+ALTER SYSTEM SET temp_buffers = 536870961;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_buffers"
+ALTER SYSTEM RESET temp_buffers;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "temp_buffers"
+SET work_mem = 1073741855;  -- ok
+RESET work_mem;  -- ok
+ALTER SYSTEM SET work_mem = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "work_mem"
+ALTER SYSTEM RESET work_mem;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "work_mem"
+-- PGC_USERSET / RESOURCES_VACUUM_DELAY
+SET vacuum_cost_delay = 50;  -- ok
+RESET vacuum_cost_delay;  -- ok
+ALTER SYSTEM SET vacuum_cost_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_delay"
+ALTER SYSTEM RESET vacuum_cost_delay;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_delay"
+SET vacuum_cost_limit = 5000;  -- ok
+RESET vacuum_cost_limit;  -- ok
+ALTER SYSTEM SET vacuum_cost_limit = 5000;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_limit"
+ALTER SYSTEM RESET vacuum_cost_limit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_limit"
+SET vacuum_cost_page_dirty = 50;  -- ok
+RESET vacuum_cost_page_dirty;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_dirty = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_dirty"
+ALTER SYSTEM RESET vacuum_cost_page_dirty;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_dirty"
+SET vacuum_cost_page_hit = 50;  -- ok
+RESET vacuum_cost_page_hit;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_hit = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_hit"
+ALTER SYSTEM RESET vacuum_cost_page_hit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_hit"
+SET vacuum_cost_page_miss = 50;  -- ok
+RESET vacuum_cost_page_miss;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_miss = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_miss"
+ALTER SYSTEM RESET vacuum_cost_page_miss;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "vacuum_cost_page_miss"
+-- PGC_USERSET / UNGROUPED
+SET seed = 0;  -- ok
+RESET seed;  -- ok
+ALTER SYSTEM SET seed = 0;  -- fail, cannot be changed
+ERROR:  parameter "seed" cannot be changed
+ALTER SYSTEM RESET seed;  -- fail, cannot be changed
+ERROR:  parameter "seed" cannot be changed
+-- PGC_USERSET / WAL_SETTINGS
+SET commit_siblings = 50;  -- ok
+RESET commit_siblings;  -- ok
+ALTER SYSTEM SET commit_siblings = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_siblings"
+ALTER SYSTEM RESET commit_siblings;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "commit_siblings"
+SET synchronous_commit = 'remote_write';  -- ok
+RESET synchronous_commit;  -- ok
+ALTER SYSTEM SET synchronous_commit = 'remote_write';  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronous_commit"
+ALTER SYSTEM RESET synchronous_commit;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "synchronous_commit"
+SET wal_skip_threshold = 50;  -- ok
+RESET wal_skip_threshold;  -- ok
+ALTER SYSTEM SET wal_skip_threshold = 50;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_skip_threshold"
+ALTER SYSTEM RESET wal_skip_threshold;  -- fail, autovacuum_admin has insufficient privileges
+ERROR:  permission denied to set parameter "wal_skip_threshold"
+RESET statement_timeout;
+RESET SESSION AUTHORIZATION;
+DROP ROLE autovacuum_admin;
diff --git a/src/test/regress/parallel_schedule b/src/test/regress/parallel_schedule
index 9ad2b077ba..e7b0585624 100644
--- a/src/test/regress/parallel_schedule
+++ b/src/test/regress/parallel_schedule
@@ -86,7 +86,7 @@ test: brin_bloom brin_multi
 # ----------
 # Another group of parallel tests
 # ----------
-test: create_table_like alter_generic alter_operator misc async dbsize misc_functions sysviews tsrf tid tidscan tidrangescan collate.icu.utf8 incremental_sort guc_priv_admin guc_priv_host_resource_admin guc_priv_vacuum_admin
+test: create_table_like alter_generic alter_operator misc async dbsize misc_functions sysviews tsrf tid tidscan tidrangescan collate.icu.utf8 incremental_sort guc_priv_admin guc_priv_host_resource_admin guc_priv_vacuum_admin guc_priv_autovacuum_admin
 
 # rules cannot run concurrently with any test that creates
 # a view or rule in the public schema
diff --git a/src/test/regress/sql/guc_priv_autovacuum_admin.sql b/src/test/regress/sql/guc_priv_autovacuum_admin.sql
new file mode 100644
index 0000000000..6f437b3f5b
--- /dev/null
+++ b/src/test/regress/sql/guc_priv_autovacuum_admin.sql
@@ -0,0 +1,1423 @@
+-- Non-superuser with privileges to configure autovacuum processes
+CREATE ROLE autovacuum_admin NOSUPERUSER;
+GRANT pg_manage_autovacuum_settings TO autovacuum_admin;
+-- Perform all operations as user 'autovacuum_admin' --
+SET SESSION AUTHORIZATION autovacuum_admin;
+-- PGC_BACKEND / DEVELOPER_OPTIONS
+SET ignore_system_indexes = OFF;  -- fail, cannot be set after connection start
+RESET ignore_system_indexes;  -- fail, cannot be set after connection start
+ALTER SYSTEM SET ignore_system_indexes = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ignore_system_indexes;  -- fail, autovacuum_admin has insufficient privileges
+SET post_auth_delay = 50;  -- fail, cannot be set after connection start
+RESET post_auth_delay;  -- fail, cannot be set after connection start
+ALTER SYSTEM SET post_auth_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET post_auth_delay;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_INTERNAL / PRESET_OPTIONS
+SET block_size = 50;  -- fail, cannot be changed
+RESET block_size;  -- fail, cannot be changed
+ALTER SYSTEM SET block_size = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET block_size;  -- fail, cannot be changed
+SET data_checksums = OFF;  -- fail, cannot be changed
+RESET data_checksums;  -- fail, cannot be changed
+ALTER SYSTEM SET data_checksums = OFF;  -- fail, cannot be changed
+ALTER SYSTEM RESET data_checksums;  -- fail, cannot be changed
+SET data_directory_mode = 50;  -- fail, cannot be changed
+RESET data_directory_mode;  -- fail, cannot be changed
+ALTER SYSTEM SET data_directory_mode = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET data_directory_mode;  -- fail, cannot be changed
+SET debug_assertions = OFF;  -- fail, cannot be changed
+RESET debug_assertions;  -- fail, cannot be changed
+ALTER SYSTEM SET debug_assertions = OFF;  -- fail, cannot be changed
+ALTER SYSTEM RESET debug_assertions;  -- fail, cannot be changed
+SET in_hot_standby = OFF;  -- fail, cannot be changed
+RESET in_hot_standby;  -- fail, cannot be changed
+ALTER SYSTEM SET in_hot_standby = OFF;  -- fail, cannot be changed
+ALTER SYSTEM RESET in_hot_standby;  -- fail, cannot be changed
+SET integer_datetimes = OFF;  -- fail, cannot be changed
+RESET integer_datetimes;  -- fail, cannot be changed
+ALTER SYSTEM SET integer_datetimes = OFF;  -- fail, cannot be changed
+ALTER SYSTEM RESET integer_datetimes;  -- fail, cannot be changed
+SET lc_collate = 'en_US.UTF-8';  -- fail, cannot be changed
+RESET lc_collate;  -- fail, cannot be changed
+ALTER SYSTEM SET lc_collate = 'en_US.UTF-8';  -- fail, cannot be changed
+ALTER SYSTEM RESET lc_collate;  -- fail, cannot be changed
+SET lc_ctype = 'en_US.UTF-8';  -- fail, cannot be changed
+RESET lc_ctype;  -- fail, cannot be changed
+ALTER SYSTEM SET lc_ctype = 'en_US.UTF-8';  -- fail, cannot be changed
+ALTER SYSTEM RESET lc_ctype;  -- fail, cannot be changed
+SET max_function_args = 50;  -- fail, cannot be changed
+RESET max_function_args;  -- fail, cannot be changed
+ALTER SYSTEM SET max_function_args = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET max_function_args;  -- fail, cannot be changed
+SET max_identifier_length = 50;  -- fail, cannot be changed
+RESET max_identifier_length;  -- fail, cannot be changed
+ALTER SYSTEM SET max_identifier_length = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET max_identifier_length;  -- fail, cannot be changed
+SET max_index_keys = 50;  -- fail, cannot be changed
+RESET max_index_keys;  -- fail, cannot be changed
+ALTER SYSTEM SET max_index_keys = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET max_index_keys;  -- fail, cannot be changed
+SET segment_size = 50;  -- fail, cannot be changed
+RESET segment_size;  -- fail, cannot be changed
+ALTER SYSTEM SET segment_size = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET segment_size;  -- fail, cannot be changed
+SET server_encoding = 'UTF8';  -- fail, cannot be changed
+RESET server_encoding;  -- fail, cannot be changed
+ALTER SYSTEM SET server_encoding = 'UTF8';  -- fail, cannot be changed
+ALTER SYSTEM RESET server_encoding;  -- fail, cannot be changed
+SET server_version = '9.1';  -- fail, cannot be changed
+RESET server_version;  -- fail, cannot be changed
+ALTER SYSTEM SET server_version = '9.1';  -- fail, cannot be changed
+ALTER SYSTEM RESET server_version;  -- fail, cannot be changed
+SET server_version_num = 50;  -- fail, cannot be changed
+RESET server_version_num;  -- fail, cannot be changed
+ALTER SYSTEM SET server_version_num = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET server_version_num;  -- fail, cannot be changed
+SET ssl_library = 'OpenSSL';  -- fail, cannot be changed
+RESET ssl_library;  -- fail, cannot be changed
+ALTER SYSTEM SET ssl_library = 'OpenSSL';  -- fail, cannot be changed
+ALTER SYSTEM RESET ssl_library;  -- fail, cannot be changed
+SET wal_block_size = 50;  -- fail, cannot be changed
+RESET wal_block_size;  -- fail, cannot be changed
+ALTER SYSTEM SET wal_block_size = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET wal_block_size;  -- fail, cannot be changed
+SET wal_segment_size = 50;  -- fail, cannot be changed
+RESET wal_segment_size;  -- fail, cannot be changed
+ALTER SYSTEM SET wal_segment_size = 50;  -- fail, cannot be changed
+ALTER SYSTEM RESET wal_segment_size;  -- fail, cannot be changed
+-- PGC_INTERNAL / UNGROUPED
+SET is_superuser = OFF;  -- fail, cannot be changed
+RESET is_superuser;  -- fail, cannot be changed
+ALTER SYSTEM SET is_superuser = OFF;  -- fail, cannot be changed
+ALTER SYSTEM RESET is_superuser;  -- fail, cannot be changed
+-- PGC_POSTMASTER / AUTOVACUUM
+SET autovacuum_freeze_max_age = 1000050000;  -- fail, requires restart
+RESET autovacuum_freeze_max_age;  -- fail, requires restart
+ALTER SYSTEM SET autovacuum_freeze_max_age = 1000050000;  -- ok
+ALTER SYSTEM RESET autovacuum_freeze_max_age;  -- ok
+SET autovacuum_max_workers = 50;  -- fail, requires restart
+RESET autovacuum_max_workers;  -- fail, requires restart
+ALTER SYSTEM SET autovacuum_max_workers = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_max_workers;  -- ok
+SET autovacuum_multixact_freeze_max_age = 1000005000;  -- fail, requires restart
+RESET autovacuum_multixact_freeze_max_age;  -- fail, requires restart
+ALTER SYSTEM SET autovacuum_multixact_freeze_max_age = 1000005000;  -- ok
+ALTER SYSTEM RESET autovacuum_multixact_freeze_max_age;  -- ok
+-- PGC_POSTMASTER / CLIENT_CONN_PRELOAD
+SET jit_provider = 'llvmjit';  -- fail, requires restart
+RESET jit_provider;  -- fail, requires restart
+ALTER SYSTEM SET jit_provider = 'llvmjit';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_provider;  -- fail, autovacuum_admin has insufficient privileges
+SET shared_preload_libraries = 'iconv, pcre';  -- fail, requires restart
+RESET shared_preload_libraries;  -- fail, requires restart
+ALTER SYSTEM SET shared_preload_libraries = 'iconv, pcre';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET shared_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / CONN_AUTH_SETTINGS
+SET bonjour = OFF;  -- fail, requires restart
+RESET bonjour;  -- fail, requires restart
+ALTER SYSTEM SET bonjour = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET bonjour;  -- fail, autovacuum_admin has insufficient privileges
+SET bonjour_name = 'BonneNuit';  -- fail, requires restart
+RESET bonjour_name;  -- fail, requires restart
+ALTER SYSTEM SET bonjour_name = 'BonneNuit';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET bonjour_name;  -- fail, autovacuum_admin has insufficient privileges
+SET listen_addresses = 'localhost';  -- fail, requires restart
+RESET listen_addresses;  -- fail, requires restart
+ALTER SYSTEM SET listen_addresses = 'localhost';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET listen_addresses;  -- fail, autovacuum_admin has insufficient privileges
+SET max_connections = 50;  -- fail, requires restart
+RESET max_connections;  -- fail, requires restart
+ALTER SYSTEM SET max_connections = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_connections;  -- fail, autovacuum_admin has insufficient privileges
+SET port = 50;  -- fail, requires restart
+RESET port;  -- fail, requires restart
+ALTER SYSTEM SET port = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET port;  -- fail, autovacuum_admin has insufficient privileges
+SET superuser_reserved_connections = 50;  -- fail, requires restart
+RESET superuser_reserved_connections;  -- fail, requires restart
+ALTER SYSTEM SET superuser_reserved_connections = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET superuser_reserved_connections;  -- fail, autovacuum_admin has insufficient privileges
+SET unix_socket_directories = '/tmp';  -- fail, requires restart
+RESET unix_socket_directories;  -- fail, requires restart
+ALTER SYSTEM SET unix_socket_directories = '/tmp';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET unix_socket_directories;  -- fail, autovacuum_admin has insufficient privileges
+SET unix_socket_group = 'tenant';  -- fail, requires restart
+RESET unix_socket_group;  -- fail, requires restart
+ALTER SYSTEM SET unix_socket_group = 'tenant';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET unix_socket_group;  -- fail, autovacuum_admin has insufficient privileges
+SET unix_socket_permissions = 50;  -- fail, requires restart
+RESET unix_socket_permissions;  -- fail, requires restart
+ALTER SYSTEM SET unix_socket_permissions = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET unix_socket_permissions;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / DEVELOPER_OPTIONS
+SET ignore_invalid_pages = OFF;  -- fail, requires restart
+RESET ignore_invalid_pages;  -- fail, requires restart
+ALTER SYSTEM SET ignore_invalid_pages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ignore_invalid_pages;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / ERROR_HANDLING_OPTIONS
+SET data_sync_retry = OFF;  -- fail, requires restart
+RESET data_sync_retry;  -- fail, requires restart
+ALTER SYSTEM SET data_sync_retry = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET data_sync_retry;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / FILE_LOCATIONS
+SET config_file = '/usr/local/data/postgresql.conf';  -- fail, requires restart
+RESET config_file;  -- fail, requires restart
+ALTER SYSTEM SET config_file = '/usr/local/data/postgresql.conf';  -- fail, cannot be changed
+ALTER SYSTEM RESET config_file;  -- fail, cannot be changed
+SET data_directory = '/usr/local/data';  -- fail, requires restart
+RESET data_directory;  -- fail, requires restart
+ALTER SYSTEM SET data_directory = '/usr/local/data';  -- fail, cannot be changed
+ALTER SYSTEM RESET data_directory;  -- fail, cannot be changed
+SET external_pid_file = '/var/postgres/master.pid';  -- fail, requires restart
+RESET external_pid_file;  -- fail, requires restart
+ALTER SYSTEM SET external_pid_file = '/var/postgres/master.pid';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET external_pid_file;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / LOCK_MANAGEMENT
+SET max_locks_per_transaction = 50;  -- fail, requires restart
+RESET max_locks_per_transaction;  -- fail, requires restart
+ALTER SYSTEM SET max_locks_per_transaction = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_locks_per_transaction;  -- fail, autovacuum_admin has insufficient privileges
+SET max_pred_locks_per_transaction = 50;  -- fail, requires restart
+RESET max_pred_locks_per_transaction;  -- fail, requires restart
+ALTER SYSTEM SET max_pred_locks_per_transaction = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_pred_locks_per_transaction;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / LOGGING_WHERE
+SET event_source = 'PostgreSQL';  -- fail, requires restart
+RESET event_source;  -- fail, requires restart
+ALTER SYSTEM SET event_source = 'PostgreSQL';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET event_source;  -- fail, autovacuum_admin has insufficient privileges
+SET logging_collector = OFF;  -- fail, requires restart
+RESET logging_collector;  -- fail, requires restart
+ALTER SYSTEM SET logging_collector = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET logging_collector;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / PROCESS_TITLE
+SET cluster_name = 'BonCluster';  -- fail, requires restart
+RESET cluster_name;  -- fail, requires restart
+ALTER SYSTEM SET cluster_name = 'BonCluster';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET cluster_name;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / REPLICATION_SENDING
+SET max_replication_slots = 50;  -- fail, requires restart
+RESET max_replication_slots;  -- fail, requires restart
+ALTER SYSTEM SET max_replication_slots = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_replication_slots;  -- fail, autovacuum_admin has insufficient privileges
+SET max_wal_senders = 50;  -- fail, requires restart
+RESET max_wal_senders;  -- fail, requires restart
+ALTER SYSTEM SET max_wal_senders = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_wal_senders;  -- fail, autovacuum_admin has insufficient privileges
+SET track_commit_timestamp = OFF;  -- fail, requires restart
+RESET track_commit_timestamp;  -- fail, requires restart
+ALTER SYSTEM SET track_commit_timestamp = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET track_commit_timestamp;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / REPLICATION_STANDBY
+SET hot_standby = OFF;  -- fail, requires restart
+RESET hot_standby;  -- fail, requires restart
+ALTER SYSTEM SET hot_standby = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET hot_standby;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / REPLICATION_SUBSCRIBERS
+SET max_logical_replication_workers = 50;  -- fail, requires restart
+RESET max_logical_replication_workers;  -- fail, requires restart
+ALTER SYSTEM SET max_logical_replication_workers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_logical_replication_workers;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / RESOURCES_ASYNCHRONOUS
+SET max_worker_processes = 50;  -- fail, requires restart
+RESET max_worker_processes;  -- fail, requires restart
+ALTER SYSTEM SET max_worker_processes = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_worker_processes;  -- fail, autovacuum_admin has insufficient privileges
+SET old_snapshot_threshold = 50;  -- fail, requires restart
+RESET old_snapshot_threshold;  -- fail, requires restart
+ALTER SYSTEM SET old_snapshot_threshold = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET old_snapshot_threshold;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / RESOURCES_KERNEL
+SET max_files_per_process = 1073741855;  -- fail, requires restart
+RESET max_files_per_process;  -- fail, requires restart
+ALTER SYSTEM SET max_files_per_process = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_files_per_process;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / RESOURCES_MEM
+SET dynamic_shared_memory_type = 'posix';  -- fail, requires restart
+RESET dynamic_shared_memory_type;  -- fail, requires restart
+ALTER SYSTEM SET dynamic_shared_memory_type = 'posix';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET dynamic_shared_memory_type;  -- fail, autovacuum_admin has insufficient privileges
+SET huge_pages = 'try';  -- fail, requires restart
+RESET huge_pages;  -- fail, requires restart
+ALTER SYSTEM SET huge_pages = 'try';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET huge_pages;  -- fail, autovacuum_admin has insufficient privileges
+SET max_prepared_transactions = 50;  -- fail, requires restart
+RESET max_prepared_transactions;  -- fail, requires restart
+ALTER SYSTEM SET max_prepared_transactions = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_prepared_transactions;  -- fail, autovacuum_admin has insufficient privileges
+SET min_dynamic_shared_memory = 50;  -- fail, requires restart
+RESET min_dynamic_shared_memory;  -- fail, requires restart
+ALTER SYSTEM SET min_dynamic_shared_memory = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET min_dynamic_shared_memory;  -- fail, autovacuum_admin has insufficient privileges
+SET shared_buffers = 50;  -- fail, requires restart
+RESET shared_buffers;  -- fail, requires restart
+ALTER SYSTEM SET shared_buffers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET shared_buffers;  -- fail, autovacuum_admin has insufficient privileges
+SET shared_memory_type = 'mmap';  -- fail, requires restart
+RESET shared_memory_type;  -- fail, requires restart
+ALTER SYSTEM SET shared_memory_type = 'mmap';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET shared_memory_type;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / STATS_COLLECTOR
+SET track_activity_query_size = 524338;  -- fail, requires restart
+RESET track_activity_query_size;  -- fail, requires restart
+ALTER SYSTEM SET track_activity_query_size = 524338;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET track_activity_query_size;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / WAL_ARCHIVING
+SET archive_mode = 'off';  -- fail, requires restart
+RESET archive_mode;  -- fail, requires restart
+ALTER SYSTEM SET archive_mode = 'off';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET archive_mode;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / WAL_RECOVERY_TARGET
+SET recovery_target_action = 'pause';  -- fail, requires restart
+RESET recovery_target_action;  -- fail, requires restart
+ALTER SYSTEM SET recovery_target_action = 'pause';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_action;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_target_inclusive = OFF;  -- fail, requires restart
+RESET recovery_target_inclusive;  -- fail, requires restart
+ALTER SYSTEM SET recovery_target_inclusive = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_inclusive;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_target_lsn = '16/B374D848';  -- fail, requires restart
+RESET recovery_target_lsn;  -- fail, requires restart
+ALTER SYSTEM SET recovery_target_lsn = '16/B374D848';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_lsn;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_target_name = 'BonPoint';  -- fail, requires restart
+RESET recovery_target_name;  -- fail, requires restart
+ALTER SYSTEM SET recovery_target_name = 'BonPoint';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_name;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_target_time = '2001-02-03 04:05:06.789 Europe/Helsinki';  -- fail, requires restart
+RESET recovery_target_time;  -- fail, requires restart
+ALTER SYSTEM SET recovery_target_time = '2001-02-03 04:05:06.789 Europe/Helsinki';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_time;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_target_timeline = 'latest';  -- fail, requires restart
+RESET recovery_target_timeline;  -- fail, requires restart
+ALTER SYSTEM SET recovery_target_timeline = 'latest';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_timeline;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_target_xid = '12345678';  -- fail, requires restart
+RESET recovery_target_xid;  -- fail, requires restart
+ALTER SYSTEM SET recovery_target_xid = '12345678';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_target_xid;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_POSTMASTER / WAL_SETTINGS
+SET wal_buffers = 50;  -- fail, requires restart
+RESET wal_buffers;  -- fail, requires restart
+ALTER SYSTEM SET wal_buffers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_buffers;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_level = 'replica';  -- fail, requires restart
+RESET wal_level;  -- fail, requires restart
+ALTER SYSTEM SET wal_level = 'replica';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_level;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_log_hints = OFF;  -- fail, requires restart
+RESET wal_log_hints;  -- fail, requires restart
+ALTER SYSTEM SET wal_log_hints = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_log_hints;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / AUTOVACUUM
+SET autovacuum = OFF;  -- fail, requires reload
+RESET autovacuum;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum = OFF;  -- ok
+ALTER SYSTEM RESET autovacuum;  -- ok
+SET autovacuum_analyze_scale_factor = 50;  -- fail, requires reload
+RESET autovacuum_analyze_scale_factor;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_analyze_scale_factor = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_analyze_scale_factor;  -- ok
+SET autovacuum_analyze_threshold = 50;  -- fail, requires reload
+RESET autovacuum_analyze_threshold;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_analyze_threshold = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_analyze_threshold;  -- ok
+SET autovacuum_naptime = 50;  -- fail, requires reload
+RESET autovacuum_naptime;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_naptime = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_naptime;  -- ok
+SET autovacuum_vacuum_cost_delay = 50;  -- fail, requires reload
+RESET autovacuum_vacuum_cost_delay;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_vacuum_cost_delay = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_cost_delay;  -- ok
+SET autovacuum_vacuum_cost_limit = 50;  -- fail, requires reload
+RESET autovacuum_vacuum_cost_limit;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_vacuum_cost_limit = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_cost_limit;  -- ok
+SET autovacuum_vacuum_insert_scale_factor = 50;  -- fail, requires reload
+RESET autovacuum_vacuum_insert_scale_factor;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_vacuum_insert_scale_factor = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_insert_scale_factor;  -- ok
+SET autovacuum_vacuum_insert_threshold = 50;  -- fail, requires reload
+RESET autovacuum_vacuum_insert_threshold;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_vacuum_insert_threshold = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_insert_threshold;  -- ok
+SET autovacuum_vacuum_scale_factor = 50;  -- fail, requires reload
+RESET autovacuum_vacuum_scale_factor;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_vacuum_scale_factor = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_scale_factor;  -- ok
+SET autovacuum_vacuum_threshold = 50;  -- fail, requires reload
+RESET autovacuum_vacuum_threshold;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_vacuum_threshold = 50;  -- ok
+ALTER SYSTEM RESET autovacuum_vacuum_threshold;  -- ok
+-- PGC_SIGHUP / CONN_AUTH_AUTH
+SET authentication_timeout = 50;  -- fail, requires reload
+RESET authentication_timeout;  -- fail, requires reload
+ALTER SYSTEM SET authentication_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET authentication_timeout;  -- fail, autovacuum_admin has insufficient privileges
+SET db_user_namespace = OFF;  -- fail, requires reload
+RESET db_user_namespace;  -- fail, requires reload
+ALTER SYSTEM SET db_user_namespace = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET db_user_namespace;  -- fail, autovacuum_admin has insufficient privileges
+SET krb_caseins_users = OFF;  -- fail, requires reload
+RESET krb_caseins_users;  -- fail, requires reload
+ALTER SYSTEM SET krb_caseins_users = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET krb_caseins_users;  -- fail, autovacuum_admin has insufficient privileges
+SET krb_server_keyfile = 'krb/server.key';  -- fail, requires reload
+RESET krb_server_keyfile;  -- fail, requires reload
+ALTER SYSTEM SET krb_server_keyfile = 'krb/server.key';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET krb_server_keyfile;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / CONN_AUTH_SSL
+SET ssl_ca_file = 'ca/server.ca';  -- fail, requires reload
+RESET ssl_ca_file;  -- fail, requires reload
+ALTER SYSTEM SET ssl_ca_file = 'ca/server.ca';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_ca_file;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_cert_file = 'crt/server.crt';  -- fail, requires reload
+RESET ssl_cert_file;  -- fail, requires reload
+ALTER SYSTEM SET ssl_cert_file = 'crt/server.crt';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_cert_file;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_ciphers = 'none';  -- fail, requires reload
+RESET ssl_ciphers;  -- fail, requires reload
+ALTER SYSTEM SET ssl_ciphers = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_ciphers;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_crl_dir = 'crl/';  -- fail, requires reload
+RESET ssl_crl_dir;  -- fail, requires reload
+ALTER SYSTEM SET ssl_crl_dir = 'crl/';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_crl_dir;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_crl_file = 'crl/server.crl';  -- fail, requires reload
+RESET ssl_crl_file;  -- fail, requires reload
+ALTER SYSTEM SET ssl_crl_file = 'crl/server.crl';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_crl_file;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_dh_params_file = 'ssl/params';  -- fail, requires reload
+RESET ssl_dh_params_file;  -- fail, requires reload
+ALTER SYSTEM SET ssl_dh_params_file = 'ssl/params';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_dh_params_file;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_ecdh_curve = 'none';  -- fail, requires reload
+RESET ssl_ecdh_curve;  -- fail, requires reload
+ALTER SYSTEM SET ssl_ecdh_curve = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_ecdh_curve;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_key_file = 'crl/server.key';  -- fail, requires reload
+RESET ssl_key_file;  -- fail, requires reload
+ALTER SYSTEM SET ssl_key_file = 'crl/server.key';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_key_file;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_min_protocol_version = 'TLSv1.2';  -- fail, requires reload
+RESET ssl_min_protocol_version;  -- fail, requires reload
+ALTER SYSTEM SET ssl_min_protocol_version = 'TLSv1.2';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_min_protocol_version;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_passphrase_command = '/bin/passphrase';  -- fail, requires reload
+RESET ssl_passphrase_command;  -- fail, requires reload
+ALTER SYSTEM SET ssl_passphrase_command = '/bin/passphrase';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_passphrase_command;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_passphrase_command_supports_reload = OFF;  -- fail, requires reload
+RESET ssl_passphrase_command_supports_reload;  -- fail, requires reload
+ALTER SYSTEM SET ssl_passphrase_command_supports_reload = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_passphrase_command_supports_reload;  -- fail, autovacuum_admin has insufficient privileges
+SET ssl_prefer_server_ciphers = OFF;  -- fail, requires reload
+RESET ssl_prefer_server_ciphers;  -- fail, requires reload
+ALTER SYSTEM SET ssl_prefer_server_ciphers = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ssl_prefer_server_ciphers;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / DEVELOPER_OPTIONS
+SET pre_auth_delay = 50;  -- fail, requires reload
+RESET pre_auth_delay;  -- fail, requires reload
+ALTER SYSTEM SET pre_auth_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET pre_auth_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET remove_temp_files_after_crash = OFF;  -- fail, requires reload
+RESET remove_temp_files_after_crash;  -- fail, requires reload
+ALTER SYSTEM SET remove_temp_files_after_crash = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET remove_temp_files_after_crash;  -- fail, autovacuum_admin has insufficient privileges
+SET trace_recovery_messages = 'log';  -- fail, requires reload
+RESET trace_recovery_messages;  -- fail, requires reload
+ALTER SYSTEM SET trace_recovery_messages = 'log';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET trace_recovery_messages;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / ERROR_HANDLING_OPTIONS
+SET recovery_init_sync_method = 'fsync';  -- fail, requires reload
+RESET recovery_init_sync_method;  -- fail, requires reload
+ALTER SYSTEM SET recovery_init_sync_method = 'fsync';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_init_sync_method;  -- fail, autovacuum_admin has insufficient privileges
+SET restart_after_crash = OFF;  -- fail, requires reload
+RESET restart_after_crash;  -- fail, requires reload
+ALTER SYSTEM SET restart_after_crash = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET restart_after_crash;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / LOCK_MANAGEMENT
+SET max_pred_locks_per_page = 50;  -- fail, requires reload
+RESET max_pred_locks_per_page;  -- fail, requires reload
+ALTER SYSTEM SET max_pred_locks_per_page = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_pred_locks_per_page;  -- fail, autovacuum_admin has insufficient privileges
+SET max_pred_locks_per_relation = 50;  -- fail, requires reload
+RESET max_pred_locks_per_relation;  -- fail, requires reload
+ALTER SYSTEM SET max_pred_locks_per_relation = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_pred_locks_per_relation;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / LOGGING_WHAT
+SET log_autovacuum_min_duration = 50;  -- fail, requires reload
+RESET log_autovacuum_min_duration;  -- fail, requires reload
+ALTER SYSTEM SET log_autovacuum_min_duration = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_autovacuum_min_duration;  -- fail, autovacuum_admin has insufficient privileges
+SET log_checkpoints = OFF;  -- fail, requires reload
+RESET log_checkpoints;  -- fail, requires reload
+ALTER SYSTEM SET log_checkpoints = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_checkpoints;  -- fail, autovacuum_admin has insufficient privileges
+SET log_hostname = OFF;  -- fail, requires reload
+RESET log_hostname;  -- fail, requires reload
+ALTER SYSTEM SET log_hostname = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_hostname;  -- fail, autovacuum_admin has insufficient privileges
+SET log_line_prefix = '%m [%p] ';  -- fail, requires reload
+RESET log_line_prefix;  -- fail, requires reload
+ALTER SYSTEM SET log_line_prefix = '%m [%p] ';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_line_prefix;  -- fail, autovacuum_admin has insufficient privileges
+SET log_recovery_conflict_waits = OFF;  -- fail, requires reload
+RESET log_recovery_conflict_waits;  -- fail, requires reload
+ALTER SYSTEM SET log_recovery_conflict_waits = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_recovery_conflict_waits;  -- fail, autovacuum_admin has insufficient privileges
+SET log_timezone = 'Europe/Helsinki';  -- fail, requires reload
+RESET log_timezone;  -- fail, requires reload
+ALTER SYSTEM SET log_timezone = 'Europe/Helsinki';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_timezone;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / LOGGING_WHERE
+SET log_directory = 'log';  -- fail, requires reload
+RESET log_directory;  -- fail, requires reload
+ALTER SYSTEM SET log_directory = 'log';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_directory;  -- fail, autovacuum_admin has insufficient privileges
+SET log_file_mode = 50;  -- fail, requires reload
+RESET log_file_mode;  -- fail, requires reload
+ALTER SYSTEM SET log_file_mode = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_file_mode;  -- fail, autovacuum_admin has insufficient privileges
+SET log_filename = 'postgresql-%Y-%m-%d_%H%M%S.log';  -- fail, requires reload
+RESET log_filename;  -- fail, requires reload
+ALTER SYSTEM SET log_filename = 'postgresql-%Y-%m-%d_%H%M%S.log';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_filename;  -- fail, autovacuum_admin has insufficient privileges
+SET log_rotation_age = 50;  -- fail, requires reload
+RESET log_rotation_age;  -- fail, requires reload
+ALTER SYSTEM SET log_rotation_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_rotation_age;  -- fail, autovacuum_admin has insufficient privileges
+SET log_rotation_size = 50;  -- fail, requires reload
+RESET log_rotation_size;  -- fail, requires reload
+ALTER SYSTEM SET log_rotation_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_rotation_size;  -- fail, autovacuum_admin has insufficient privileges
+SET log_truncate_on_rotation = OFF;  -- fail, requires reload
+RESET log_truncate_on_rotation;  -- fail, requires reload
+ALTER SYSTEM SET log_truncate_on_rotation = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_truncate_on_rotation;  -- fail, autovacuum_admin has insufficient privileges
+SET syslog_ident = 'postgres';  -- fail, requires reload
+RESET syslog_ident;  -- fail, requires reload
+ALTER SYSTEM SET syslog_ident = 'postgres';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET syslog_ident;  -- fail, autovacuum_admin has insufficient privileges
+SET syslog_sequence_numbers = OFF;  -- fail, requires reload
+RESET syslog_sequence_numbers;  -- fail, requires reload
+ALTER SYSTEM SET syslog_sequence_numbers = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET syslog_sequence_numbers;  -- fail, autovacuum_admin has insufficient privileges
+SET syslog_split_messages = OFF;  -- fail, requires reload
+RESET syslog_split_messages;  -- fail, requires reload
+ALTER SYSTEM SET syslog_split_messages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET syslog_split_messages;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / REPLICATION_PRIMARY
+SET synchronous_standby_names = 'fee, fi, fo, fum';  -- fail, requires reload
+RESET synchronous_standby_names;  -- fail, requires reload
+ALTER SYSTEM SET synchronous_standby_names = 'fee, fi, fo, fum';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET synchronous_standby_names;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_defer_cleanup_age = 50;  -- fail, requires reload
+RESET vacuum_defer_cleanup_age;  -- fail, requires reload
+ALTER SYSTEM SET vacuum_defer_cleanup_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_defer_cleanup_age;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / REPLICATION_SENDING
+SET max_slot_wal_keep_size = 50;  -- fail, requires reload
+RESET max_slot_wal_keep_size;  -- fail, requires reload
+ALTER SYSTEM SET max_slot_wal_keep_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_slot_wal_keep_size;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_keep_size = 50;  -- fail, requires reload
+RESET wal_keep_size;  -- fail, requires reload
+ALTER SYSTEM SET wal_keep_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_keep_size;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / REPLICATION_STANDBY
+SET hot_standby_feedback = OFF;  -- fail, requires reload
+RESET hot_standby_feedback;  -- fail, requires reload
+ALTER SYSTEM SET hot_standby_feedback = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET hot_standby_feedback;  -- fail, autovacuum_admin has insufficient privileges
+SET max_standby_archive_delay = 50;  -- fail, requires reload
+RESET max_standby_archive_delay;  -- fail, requires reload
+ALTER SYSTEM SET max_standby_archive_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_standby_archive_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET max_standby_streaming_delay = 50;  -- fail, requires reload
+RESET max_standby_streaming_delay;  -- fail, requires reload
+ALTER SYSTEM SET max_standby_streaming_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_standby_streaming_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET primary_conninfo = 'postgresql://other@localhost/otherdb?connect_timeout=10&application_name=myapp';  -- fail, requires reload
+RESET primary_conninfo;  -- fail, requires reload
+ALTER SYSTEM SET primary_conninfo = 'postgresql://other@localhost/otherdb?connect_timeout=10&application_name=myapp';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET primary_conninfo;  -- fail, autovacuum_admin has insufficient privileges
+SET primary_slot_name = 'bonne_fente';  -- fail, requires reload
+RESET primary_slot_name;  -- fail, requires reload
+ALTER SYSTEM SET primary_slot_name = 'bonne_fente';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET primary_slot_name;  -- fail, autovacuum_admin has insufficient privileges
+SET promote_trigger_file = 'promote.trigger';  -- fail, requires reload
+RESET promote_trigger_file;  -- fail, requires reload
+ALTER SYSTEM SET promote_trigger_file = 'promote.trigger';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET promote_trigger_file;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_min_apply_delay = 50;  -- fail, requires reload
+RESET recovery_min_apply_delay;  -- fail, requires reload
+ALTER SYSTEM SET recovery_min_apply_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_min_apply_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_receiver_create_temp_slot = OFF;  -- fail, requires reload
+RESET wal_receiver_create_temp_slot;  -- fail, requires reload
+ALTER SYSTEM SET wal_receiver_create_temp_slot = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_receiver_create_temp_slot;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_receiver_status_interval = 50;  -- fail, requires reload
+RESET wal_receiver_status_interval;  -- fail, requires reload
+ALTER SYSTEM SET wal_receiver_status_interval = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_receiver_status_interval;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_receiver_timeout = 50;  -- fail, requires reload
+RESET wal_receiver_timeout;  -- fail, requires reload
+ALTER SYSTEM SET wal_receiver_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_receiver_timeout;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_retrieve_retry_interval = 50;  -- fail, requires reload
+RESET wal_retrieve_retry_interval;  -- fail, requires reload
+ALTER SYSTEM SET wal_retrieve_retry_interval = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_retrieve_retry_interval;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / REPLICATION_SUBSCRIBERS
+SET max_sync_workers_per_subscription = 50;  -- fail, requires reload
+RESET max_sync_workers_per_subscription;  -- fail, requires reload
+ALTER SYSTEM SET max_sync_workers_per_subscription = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_sync_workers_per_subscription;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / RESOURCES_BGWRITER
+SET bgwriter_delay = 50;  -- fail, requires reload
+RESET bgwriter_delay;  -- fail, requires reload
+ALTER SYSTEM SET bgwriter_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET bgwriter_flush_after = 50;  -- fail, requires reload
+RESET bgwriter_flush_after;  -- fail, requires reload
+ALTER SYSTEM SET bgwriter_flush_after = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+SET bgwriter_lru_maxpages = 50;  -- fail, requires reload
+RESET bgwriter_lru_maxpages;  -- fail, requires reload
+ALTER SYSTEM SET bgwriter_lru_maxpages = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_lru_maxpages;  -- fail, autovacuum_admin has insufficient privileges
+SET bgwriter_lru_multiplier = 5;  -- fail, requires reload
+RESET bgwriter_lru_multiplier;  -- fail, requires reload
+ALTER SYSTEM SET bgwriter_lru_multiplier = 5;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET bgwriter_lru_multiplier;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / RESOURCES_MEM
+SET autovacuum_work_mem = 50;  -- fail, requires reload
+RESET autovacuum_work_mem;  -- fail, requires reload
+ALTER SYSTEM SET autovacuum_work_mem = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET autovacuum_work_mem;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / STATS_COLLECTOR
+SET stats_temp_directory = 'pg_stat_tmp';  -- fail, requires reload
+RESET stats_temp_directory;  -- fail, requires reload
+ALTER SYSTEM SET stats_temp_directory = 'pg_stat_tmp';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET stats_temp_directory;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_ARCHIVE_RECOVERY
+SET archive_cleanup_command = '/bin/cleanup my stuff';  -- fail, requires reload
+RESET archive_cleanup_command;  -- fail, requires reload
+ALTER SYSTEM SET archive_cleanup_command = '/bin/cleanup my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET archive_cleanup_command;  -- fail, autovacuum_admin has insufficient privileges
+SET recovery_end_command = '/bin/recover my stuff';  -- fail, requires reload
+RESET recovery_end_command;  -- fail, requires reload
+ALTER SYSTEM SET recovery_end_command = '/bin/recover my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET recovery_end_command;  -- fail, autovacuum_admin has insufficient privileges
+SET restore_command = '/bin/restore my stuff';  -- fail, requires reload
+RESET restore_command;  -- fail, requires reload
+ALTER SYSTEM SET restore_command = '/bin/restore my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET restore_command;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_ARCHIVING
+SET archive_command = '/bin/archive my stuff';  -- fail, requires reload
+RESET archive_command;  -- fail, requires reload
+ALTER SYSTEM SET archive_command = '/bin/archive my stuff';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET archive_command;  -- fail, autovacuum_admin has insufficient privileges
+SET archive_timeout = 50;  -- fail, requires reload
+RESET archive_timeout;  -- fail, requires reload
+ALTER SYSTEM SET archive_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET archive_timeout;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_CHECKPOINTS
+SET checkpoint_completion_target = 0;  -- fail, requires reload
+RESET checkpoint_completion_target;  -- fail, requires reload
+ALTER SYSTEM SET checkpoint_completion_target = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_completion_target;  -- fail, autovacuum_admin has insufficient privileges
+SET checkpoint_flush_after = 50;  -- fail, requires reload
+RESET checkpoint_flush_after;  -- fail, requires reload
+ALTER SYSTEM SET checkpoint_flush_after = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+SET checkpoint_timeout = 50;  -- fail, requires reload
+RESET checkpoint_timeout;  -- fail, requires reload
+ALTER SYSTEM SET checkpoint_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_timeout;  -- fail, autovacuum_admin has insufficient privileges
+SET checkpoint_warning = 50;  -- fail, requires reload
+RESET checkpoint_warning;  -- fail, requires reload
+ALTER SYSTEM SET checkpoint_warning = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET checkpoint_warning;  -- fail, autovacuum_admin has insufficient privileges
+SET max_wal_size = 50;  -- fail, requires reload
+RESET max_wal_size;  -- fail, requires reload
+ALTER SYSTEM SET max_wal_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_wal_size;  -- fail, autovacuum_admin has insufficient privileges
+SET min_wal_size = 50;  -- fail, requires reload
+RESET min_wal_size;  -- fail, requires reload
+ALTER SYSTEM SET min_wal_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET min_wal_size;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SIGHUP / WAL_SETTINGS
+SET fsync = OFF;  -- fail, requires reload
+RESET fsync;  -- fail, requires reload
+ALTER SYSTEM SET fsync = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET fsync;  -- fail, autovacuum_admin has insufficient privileges
+SET full_page_writes = OFF;  -- fail, requires reload
+RESET full_page_writes;  -- fail, requires reload
+ALTER SYSTEM SET full_page_writes = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET full_page_writes;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_sync_method = 'open_datasync';  -- fail, requires reload
+RESET wal_sync_method;  -- fail, requires reload
+ALTER SYSTEM SET wal_sync_method = 'open_datasync';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_sync_method;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_writer_delay = 50;  -- fail, requires reload
+RESET wal_writer_delay;  -- fail, requires reload
+ALTER SYSTEM SET wal_writer_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_writer_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_writer_flush_after = 50;  -- fail, requires reload
+RESET wal_writer_flush_after;  -- fail, requires reload
+ALTER SYSTEM SET wal_writer_flush_after = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_writer_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_LOCALE
+SET lc_messages = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+RESET lc_messages;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET lc_messages = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET lc_messages;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_OTHER
+SET dynamic_library_path = '$libdir';  -- fail, autovacuum_admin has insufficient privileges
+RESET dynamic_library_path;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET dynamic_library_path = '$libdir';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET dynamic_library_path;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_PRELOAD
+SET session_preload_libraries = 'gssapi_krb5';  -- fail, autovacuum_admin has insufficient privileges
+RESET session_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET session_preload_libraries = 'gssapi_krb5';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET session_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / CLIENT_CONN_STATEMENT
+SET session_replication_role = 'origin';  -- fail, autovacuum_admin has insufficient privileges
+RESET session_replication_role;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET session_replication_role = 'origin';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET session_replication_role;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / COMPAT_OPTIONS_PREVIOUS
+SET lo_compat_privileges = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET lo_compat_privileges;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET lo_compat_privileges = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET lo_compat_privileges;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / DEVELOPER_OPTIONS
+SET allow_system_table_mods = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET allow_system_table_mods;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET allow_system_table_mods = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET allow_system_table_mods;  -- fail, autovacuum_admin has insufficient privileges
+SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, autovacuum_admin has insufficient privileges
+RESET backtrace_functions;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET backtrace_functions = 'partition_list_bsearch,partition_range_datum_bsearch,partition_hash_bsearch';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET backtrace_functions;  -- fail, autovacuum_admin has insufficient privileges
+SET debug_discard_caches = 2;  -- fail, autovacuum_admin has insufficient privileges
+RESET debug_discard_caches;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET debug_discard_caches = 2;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET debug_discard_caches;  -- fail, autovacuum_admin has insufficient privileges
+SET ignore_checksum_failure = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET ignore_checksum_failure;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET ignore_checksum_failure = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET ignore_checksum_failure;  -- fail, autovacuum_admin has insufficient privileges
+SET jit_dump_bitcode = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET jit_dump_bitcode;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET jit_dump_bitcode = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_dump_bitcode;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, autovacuum_admin has insufficient privileges
+RESET wal_consistency_checking;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET wal_consistency_checking = 'heap, heap2, btree, hash, gin, gist, sequence, spgist, brin, generic';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_consistency_checking;  -- fail, autovacuum_admin has insufficient privileges
+SET zero_damaged_pages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET zero_damaged_pages;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET zero_damaged_pages = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET zero_damaged_pages;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / LOCK_MANAGEMENT
+SET deadlock_timeout = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+RESET deadlock_timeout;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET deadlock_timeout = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET deadlock_timeout;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / LOGGING_WHAT
+SET log_duration = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_duration;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_duration = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_duration;  -- fail, autovacuum_admin has insufficient privileges
+SET log_error_verbosity = 'default';  -- fail, autovacuum_admin has insufficient privileges
+RESET log_error_verbosity;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_error_verbosity = 'default';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_error_verbosity;  -- fail, autovacuum_admin has insufficient privileges
+SET log_lock_waits = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_lock_waits;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_lock_waits = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_lock_waits;  -- fail, autovacuum_admin has insufficient privileges
+SET log_parameter_max_length = 50;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_parameter_max_length;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_parameter_max_length = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_parameter_max_length;  -- fail, autovacuum_admin has insufficient privileges
+SET log_replication_commands = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_replication_commands;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_replication_commands = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_replication_commands;  -- fail, autovacuum_admin has insufficient privileges
+SET log_statement = 'none';  -- fail, autovacuum_admin has insufficient privileges
+RESET log_statement;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_statement = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_statement;  -- fail, autovacuum_admin has insufficient privileges
+SET log_temp_files = 50;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_temp_files;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_temp_files = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_temp_files;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / LOGGING_WHEN
+SET log_min_duration_sample = 50;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_min_duration_sample;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_min_duration_sample = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_duration_sample;  -- fail, autovacuum_admin has insufficient privileges
+SET log_min_duration_statement = 50;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_min_duration_statement;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_min_duration_statement = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_duration_statement;  -- fail, autovacuum_admin has insufficient privileges
+SET log_min_error_statement = 'error';  -- fail, autovacuum_admin has insufficient privileges
+RESET log_min_error_statement;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_min_error_statement = 'error';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_error_statement;  -- fail, autovacuum_admin has insufficient privileges
+SET log_min_messages = 'warning';  -- fail, autovacuum_admin has insufficient privileges
+RESET log_min_messages;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_min_messages = 'warning';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_min_messages;  -- fail, autovacuum_admin has insufficient privileges
+SET log_statement_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_statement_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_statement_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_statement_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+SET log_transaction_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_transaction_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_transaction_sample_rate = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_transaction_sample_rate;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / PROCESS_TITLE
+SET update_process_title = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET update_process_title;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET update_process_title = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET update_process_title;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / RESOURCES_DISK
+SET temp_file_limit = 50;  -- fail, autovacuum_admin has insufficient privileges
+RESET temp_file_limit;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET temp_file_limit = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET temp_file_limit;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / RESOURCES_MEM
+SET max_stack_depth = 3890;  -- fail, autovacuum_admin has insufficient privileges
+RESET max_stack_depth;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET max_stack_depth = 3890;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_stack_depth;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / STATS_COLLECTOR
+SET track_activities = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET track_activities;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET track_activities = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET track_activities;  -- fail, autovacuum_admin has insufficient privileges
+SET track_counts = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET track_counts;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET track_counts = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET track_counts;  -- fail, autovacuum_admin has insufficient privileges
+SET track_functions = 'none';  -- fail, autovacuum_admin has insufficient privileges
+RESET track_functions;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET track_functions = 'none';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET track_functions;  -- fail, autovacuum_admin has insufficient privileges
+SET track_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET track_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET track_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET track_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+SET track_wal_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET track_wal_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET track_wal_io_timing = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET track_wal_io_timing;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / STATS_MONITORING
+SET compute_query_id = 'auto';  -- fail, autovacuum_admin has insufficient privileges
+RESET compute_query_id;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET compute_query_id = 'auto';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET compute_query_id;  -- fail, autovacuum_admin has insufficient privileges
+SET log_executor_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_executor_stats;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_executor_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_executor_stats;  -- fail, autovacuum_admin has insufficient privileges
+SET log_parser_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_parser_stats;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_parser_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_parser_stats;  -- fail, autovacuum_admin has insufficient privileges
+SET log_planner_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_planner_stats;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_planner_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_planner_stats;  -- fail, autovacuum_admin has insufficient privileges
+SET log_statement_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET log_statement_stats;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET log_statement_stats = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_statement_stats;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SUSET / WAL_SETTINGS
+SET commit_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+RESET commit_delay;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET commit_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET commit_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_compression = 'pglz';  -- fail, autovacuum_admin has insufficient privileges
+RESET wal_compression;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET wal_compression = 'pglz';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_compression;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_init_zero = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET wal_init_zero;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET wal_init_zero = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_init_zero;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_recycle = OFF;  -- fail, autovacuum_admin has insufficient privileges
+RESET wal_recycle;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM SET wal_recycle = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_recycle;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SU_BACKEND / DEVELOPER_OPTIONS
+SET jit_debugging_support = OFF;  -- fail, cannot be set after connection start
+RESET jit_debugging_support;  -- fail, cannot be set after connection start
+ALTER SYSTEM SET jit_debugging_support = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_debugging_support;  -- fail, autovacuum_admin has insufficient privileges
+SET jit_profiling_support = OFF;  -- fail, cannot be set after connection start
+RESET jit_profiling_support;  -- fail, cannot be set after connection start
+ALTER SYSTEM SET jit_profiling_support = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_profiling_support;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_SU_BACKEND / LOGGING_WHAT
+SET log_connections = OFF;  -- fail, cannot be set after connection start
+RESET log_connections;  -- fail, cannot be set after connection start
+ALTER SYSTEM SET log_connections = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_connections;  -- fail, autovacuum_admin has insufficient privileges
+SET log_disconnections = OFF;  -- fail, cannot be set after connection start
+RESET log_disconnections;  -- fail, cannot be set after connection start
+ALTER SYSTEM SET log_disconnections = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_disconnections;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_LOCALE
+SET DateStyle = 'ISO, MDY';  -- ok
+RESET DateStyle;  -- ok
+ALTER SYSTEM SET DateStyle = 'ISO, MDY';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET DateStyle;  -- fail, autovacuum_admin has insufficient privileges
+SET IntervalStyle = 'postgres';  -- ok
+RESET IntervalStyle;  -- ok
+ALTER SYSTEM SET IntervalStyle = 'postgres';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET IntervalStyle;  -- fail, autovacuum_admin has insufficient privileges
+SET TimeZone = 'Europe/Helsinki';  -- ok
+RESET TimeZone;  -- ok
+ALTER SYSTEM SET TimeZone = 'Europe/Helsinki';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET TimeZone;  -- fail, autovacuum_admin has insufficient privileges
+SET client_encoding = 'UTF8';  -- ok
+RESET client_encoding;  -- ok
+ALTER SYSTEM SET client_encoding = 'UTF8';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET client_encoding;  -- fail, autovacuum_admin has insufficient privileges
+SET default_text_search_config = 'pg_catalog.english';  -- ok
+RESET default_text_search_config;  -- ok
+ALTER SYSTEM SET default_text_search_config = 'pg_catalog.english';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET default_text_search_config;  -- fail, autovacuum_admin has insufficient privileges
+SET extra_float_digits = -6;  -- ok
+RESET extra_float_digits;  -- ok
+ALTER SYSTEM SET extra_float_digits = -6;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET extra_float_digits;  -- fail, autovacuum_admin has insufficient privileges
+SET lc_monetary = 'en_US.UTF-8';  -- ok
+RESET lc_monetary;  -- ok
+ALTER SYSTEM SET lc_monetary = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET lc_monetary;  -- fail, autovacuum_admin has insufficient privileges
+SET lc_numeric = 'en_US.UTF-8';  -- ok
+RESET lc_numeric;  -- ok
+ALTER SYSTEM SET lc_numeric = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET lc_numeric;  -- fail, autovacuum_admin has insufficient privileges
+SET lc_time = 'en_US.UTF-8';  -- ok
+RESET lc_time;  -- ok
+ALTER SYSTEM SET lc_time = 'en_US.UTF-8';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET lc_time;  -- fail, autovacuum_admin has insufficient privileges
+SET timezone_abbreviations = 'Default';  -- ok
+RESET timezone_abbreviations;  -- ok
+ALTER SYSTEM SET timezone_abbreviations = 'Default';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET timezone_abbreviations;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_OTHER
+SET gin_fuzzy_search_limit = 50;  -- ok
+RESET gin_fuzzy_search_limit;  -- ok
+ALTER SYSTEM SET gin_fuzzy_search_limit = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET gin_fuzzy_search_limit;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_PRELOAD
+SET local_preload_libraries = 'gssapi_krb5';  -- ok
+RESET local_preload_libraries;  -- ok
+ALTER SYSTEM SET local_preload_libraries = 'gssapi_krb5';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET local_preload_libraries;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / CLIENT_CONN_STATEMENT
+SET bytea_output = 'hex';  -- ok
+RESET bytea_output;  -- ok
+ALTER SYSTEM SET bytea_output = 'hex';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET bytea_output;  -- fail, autovacuum_admin has insufficient privileges
+SET check_function_bodies = OFF;  -- ok
+RESET check_function_bodies;  -- ok
+ALTER SYSTEM SET check_function_bodies = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET check_function_bodies;  -- fail, autovacuum_admin has insufficient privileges
+SET client_min_messages = 'notice';  -- ok
+RESET client_min_messages;  -- ok
+ALTER SYSTEM SET client_min_messages = 'notice';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET client_min_messages;  -- fail, autovacuum_admin has insufficient privileges
+SET default_table_access_method = 'heap';  -- ok
+RESET default_table_access_method;  -- ok
+ALTER SYSTEM SET default_table_access_method = 'heap';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET default_table_access_method;  -- fail, autovacuum_admin has insufficient privileges
+SET default_toast_compression = 'pglz';  -- ok
+RESET default_toast_compression;  -- ok
+ALTER SYSTEM SET default_toast_compression = 'pglz';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET default_toast_compression;  -- fail, autovacuum_admin has insufficient privileges
+SET default_transaction_deferrable = OFF;  -- ok
+RESET default_transaction_deferrable;  -- ok
+ALTER SYSTEM SET default_transaction_deferrable = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET default_transaction_deferrable;  -- fail, autovacuum_admin has insufficient privileges
+SET default_transaction_isolation = 'read committed';  -- ok
+RESET default_transaction_isolation;  -- ok
+ALTER SYSTEM SET default_transaction_isolation = 'read committed';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET default_transaction_isolation;  -- fail, autovacuum_admin has insufficient privileges
+SET default_transaction_read_only = OFF;  -- ok
+RESET default_transaction_read_only;  -- ok
+ALTER SYSTEM SET default_transaction_read_only = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET default_transaction_read_only;  -- fail, autovacuum_admin has insufficient privileges
+SET gin_pending_list_limit = 1073741855;  -- ok
+RESET gin_pending_list_limit;  -- ok
+ALTER SYSTEM SET gin_pending_list_limit = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET gin_pending_list_limit;  -- fail, autovacuum_admin has insufficient privileges
+SET idle_in_transaction_session_timeout = 50;  -- ok
+RESET idle_in_transaction_session_timeout;  -- ok
+ALTER SYSTEM SET idle_in_transaction_session_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET idle_in_transaction_session_timeout;  -- fail, autovacuum_admin has insufficient privileges
+SET idle_session_timeout = 50;  -- ok
+RESET idle_session_timeout;  -- ok
+ALTER SYSTEM SET idle_session_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET idle_session_timeout;  -- fail, autovacuum_admin has insufficient privileges
+SET lock_timeout = 50;  -- ok
+RESET lock_timeout;  -- ok
+ALTER SYSTEM SET lock_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET lock_timeout;  -- fail, autovacuum_admin has insufficient privileges
+SET row_security = OFF;  -- ok
+RESET row_security;  -- ok
+ALTER SYSTEM SET row_security = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET row_security;  -- fail, autovacuum_admin has insufficient privileges
+SET search_path = '"$user", public';  -- ok
+RESET search_path;  -- ok
+ALTER SYSTEM SET search_path = '"$user", public';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET search_path;  -- fail, autovacuum_admin has insufficient privileges
+SET statement_timeout = 5250;  -- ok
+RESET statement_timeout;  -- ok
+ALTER SYSTEM SET statement_timeout = 5250;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET statement_timeout;  -- fail, autovacuum_admin has insufficient privileges
+SET transaction_deferrable = OFF;  -- ok
+RESET transaction_deferrable;  -- ok
+ALTER SYSTEM SET transaction_deferrable = OFF;  -- fail, cannot be changed
+ALTER SYSTEM RESET transaction_deferrable;  -- fail, cannot be changed
+SET transaction_read_only = OFF;  -- ok
+RESET transaction_read_only;  -- ok
+ALTER SYSTEM SET transaction_read_only = OFF;  -- fail, cannot be changed
+ALTER SYSTEM RESET transaction_read_only;  -- fail, cannot be changed
+SET vacuum_failsafe_age = 50;  -- ok
+RESET vacuum_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_failsafe_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_failsafe_age;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_freeze_min_age = 50;  -- ok
+RESET vacuum_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_min_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_freeze_min_age;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_freeze_table_age = 50;  -- ok
+RESET vacuum_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_freeze_table_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_freeze_table_age;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_multixact_failsafe_age = 50;  -- ok
+RESET vacuum_multixact_failsafe_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_failsafe_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_multixact_failsafe_age;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_multixact_freeze_min_age = 50;  -- ok
+RESET vacuum_multixact_freeze_min_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_min_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_multixact_freeze_min_age;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_multixact_freeze_table_age = 50;  -- ok
+RESET vacuum_multixact_freeze_table_age;  -- ok
+ALTER SYSTEM SET vacuum_multixact_freeze_table_age = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_multixact_freeze_table_age;  -- fail, autovacuum_admin has insufficient privileges
+SET xmlbinary = 'base64';  -- ok
+RESET xmlbinary;  -- ok
+ALTER SYSTEM SET xmlbinary = 'base64';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET xmlbinary;  -- fail, autovacuum_admin has insufficient privileges
+SET xmloption = 'content';  -- ok
+RESET xmloption;  -- ok
+ALTER SYSTEM SET xmloption = 'content';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET xmloption;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / COMPAT_OPTIONS_PREVIOUS
+SET array_nulls = OFF;  -- ok
+RESET array_nulls;  -- ok
+ALTER SYSTEM SET array_nulls = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET array_nulls;  -- fail, autovacuum_admin has insufficient privileges
+SET escape_string_warning = OFF;  -- ok
+RESET escape_string_warning;  -- ok
+ALTER SYSTEM SET escape_string_warning = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET escape_string_warning;  -- fail, autovacuum_admin has insufficient privileges
+SET quote_all_identifiers = OFF;  -- ok
+RESET quote_all_identifiers;  -- ok
+ALTER SYSTEM SET quote_all_identifiers = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET quote_all_identifiers;  -- fail, autovacuum_admin has insufficient privileges
+SET standard_conforming_strings = OFF;  -- ok
+RESET standard_conforming_strings;  -- ok
+ALTER SYSTEM SET standard_conforming_strings = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET standard_conforming_strings;  -- fail, autovacuum_admin has insufficient privileges
+SET synchronize_seqscans = OFF;  -- ok
+RESET synchronize_seqscans;  -- ok
+ALTER SYSTEM SET synchronize_seqscans = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET synchronize_seqscans;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / CONN_AUTH_AUTH
+SET password_encryption = 'scram-sha-256';  -- ok
+RESET password_encryption;  -- ok
+ALTER SYSTEM SET password_encryption = 'scram-sha-256';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET password_encryption;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / CONN_AUTH_SETTINGS
+SET client_connection_check_interval = 0;  -- ok
+RESET client_connection_check_interval;  -- ok
+ALTER SYSTEM SET client_connection_check_interval = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET client_connection_check_interval;  -- fail, autovacuum_admin has insufficient privileges
+SET tcp_keepalives_count = 50;  -- ok
+RESET tcp_keepalives_count;  -- ok
+ALTER SYSTEM SET tcp_keepalives_count = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_keepalives_count;  -- fail, autovacuum_admin has insufficient privileges
+SET tcp_keepalives_idle = 50;  -- ok
+RESET tcp_keepalives_idle;  -- ok
+ALTER SYSTEM SET tcp_keepalives_idle = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_keepalives_idle;  -- fail, autovacuum_admin has insufficient privileges
+SET tcp_keepalives_interval = 50;  -- ok
+RESET tcp_keepalives_interval;  -- ok
+ALTER SYSTEM SET tcp_keepalives_interval = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_keepalives_interval;  -- fail, autovacuum_admin has insufficient privileges
+SET tcp_user_timeout = 50;  -- ok
+RESET tcp_user_timeout;  -- ok
+ALTER SYSTEM SET tcp_user_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET tcp_user_timeout;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / CONN_AUTH_SSL
+SET ssl_renegotiation_limit = 0;  -- ok
+RESET ssl_renegotiation_limit;  -- ok
+ALTER SYSTEM SET ssl_renegotiation_limit = 0;  -- fail, cannot be changed
+ALTER SYSTEM RESET ssl_renegotiation_limit;  -- fail, cannot be changed
+-- PGC_USERSET / DEVELOPER_OPTIONS
+SET force_parallel_mode = 'off';  -- ok
+RESET force_parallel_mode;  -- ok
+ALTER SYSTEM SET force_parallel_mode = 'off';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET force_parallel_mode;  -- fail, autovacuum_admin has insufficient privileges
+SET jit_expressions = OFF;  -- ok
+RESET jit_expressions;  -- ok
+ALTER SYSTEM SET jit_expressions = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_expressions;  -- fail, autovacuum_admin has insufficient privileges
+SET jit_tuple_deforming = OFF;  -- ok
+RESET jit_tuple_deforming;  -- ok
+ALTER SYSTEM SET jit_tuple_deforming = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_tuple_deforming;  -- fail, autovacuum_admin has insufficient privileges
+SET trace_notify = OFF;  -- ok
+RESET trace_notify;  -- ok
+ALTER SYSTEM SET trace_notify = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET trace_notify;  -- fail, autovacuum_admin has insufficient privileges
+SET trace_sort = OFF;  -- ok
+RESET trace_sort;  -- ok
+ALTER SYSTEM SET trace_sort = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET trace_sort;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / ERROR_HANDLING_OPTIONS
+SET exit_on_error = OFF;  -- ok
+RESET exit_on_error;  -- ok
+ALTER SYSTEM SET exit_on_error = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET exit_on_error;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / LOGGING_WHAT
+SET application_name = 'psql';  -- ok
+RESET application_name;  -- ok
+ALTER SYSTEM SET application_name = 'psql';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET application_name;  -- fail, autovacuum_admin has insufficient privileges
+SET debug_pretty_print = OFF;  -- ok
+RESET debug_pretty_print;  -- ok
+ALTER SYSTEM SET debug_pretty_print = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET debug_pretty_print;  -- fail, autovacuum_admin has insufficient privileges
+SET debug_print_parse = OFF;  -- ok
+RESET debug_print_parse;  -- ok
+ALTER SYSTEM SET debug_print_parse = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET debug_print_parse;  -- fail, autovacuum_admin has insufficient privileges
+SET debug_print_plan = OFF;  -- ok
+RESET debug_print_plan;  -- ok
+ALTER SYSTEM SET debug_print_plan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET debug_print_plan;  -- fail, autovacuum_admin has insufficient privileges
+SET debug_print_rewritten = OFF;  -- ok
+RESET debug_print_rewritten;  -- ok
+ALTER SYSTEM SET debug_print_rewritten = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET debug_print_rewritten;  -- fail, autovacuum_admin has insufficient privileges
+SET log_parameter_max_length_on_error = 50;  -- ok
+RESET log_parameter_max_length_on_error;  -- ok
+ALTER SYSTEM SET log_parameter_max_length_on_error = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET log_parameter_max_length_on_error;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_COST
+SET cpu_index_tuple_cost = 50;  -- ok
+RESET cpu_index_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_index_tuple_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET cpu_index_tuple_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET cpu_operator_cost = 50;  -- ok
+RESET cpu_operator_cost;  -- ok
+ALTER SYSTEM SET cpu_operator_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET cpu_operator_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET cpu_tuple_cost = 50;  -- ok
+RESET cpu_tuple_cost;  -- ok
+ALTER SYSTEM SET cpu_tuple_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET cpu_tuple_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET effective_cache_size = 1073741824;  -- ok
+RESET effective_cache_size;  -- ok
+ALTER SYSTEM SET effective_cache_size = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET effective_cache_size;  -- fail, autovacuum_admin has insufficient privileges
+SET jit_above_cost = 50;  -- ok
+RESET jit_above_cost;  -- ok
+ALTER SYSTEM SET jit_above_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_above_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET jit_inline_above_cost = 50;  -- ok
+RESET jit_inline_above_cost;  -- ok
+ALTER SYSTEM SET jit_inline_above_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_inline_above_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET jit_optimize_above_cost = 50;  -- ok
+RESET jit_optimize_above_cost;  -- ok
+ALTER SYSTEM SET jit_optimize_above_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit_optimize_above_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET min_parallel_index_scan_size = 50;  -- ok
+RESET min_parallel_index_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_index_scan_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET min_parallel_index_scan_size;  -- fail, autovacuum_admin has insufficient privileges
+SET min_parallel_table_scan_size = 50;  -- ok
+RESET min_parallel_table_scan_size;  -- ok
+ALTER SYSTEM SET min_parallel_table_scan_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET min_parallel_table_scan_size;  -- fail, autovacuum_admin has insufficient privileges
+SET parallel_setup_cost = 50;  -- ok
+RESET parallel_setup_cost;  -- ok
+ALTER SYSTEM SET parallel_setup_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET parallel_setup_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET parallel_tuple_cost = 50;  -- ok
+RESET parallel_tuple_cost;  -- ok
+ALTER SYSTEM SET parallel_tuple_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET parallel_tuple_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET random_page_cost = 50;  -- ok
+RESET random_page_cost;  -- ok
+ALTER SYSTEM SET random_page_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET random_page_cost;  -- fail, autovacuum_admin has insufficient privileges
+SET seq_page_cost = 50;  -- ok
+RESET seq_page_cost;  -- ok
+ALTER SYSTEM SET seq_page_cost = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET seq_page_cost;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_GEQO
+SET geqo = OFF;  -- ok
+RESET geqo;  -- ok
+ALTER SYSTEM SET geqo = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET geqo;  -- fail, autovacuum_admin has insufficient privileges
+SET geqo_effort = 5;  -- ok
+RESET geqo_effort;  -- ok
+ALTER SYSTEM SET geqo_effort = 5;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_effort;  -- fail, autovacuum_admin has insufficient privileges
+SET geqo_generations = 50;  -- ok
+RESET geqo_generations;  -- ok
+ALTER SYSTEM SET geqo_generations = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_generations;  -- fail, autovacuum_admin has insufficient privileges
+SET geqo_pool_size = 50;  -- ok
+RESET geqo_pool_size;  -- ok
+ALTER SYSTEM SET geqo_pool_size = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_pool_size;  -- fail, autovacuum_admin has insufficient privileges
+SET geqo_seed = 0;  -- ok
+RESET geqo_seed;  -- ok
+ALTER SYSTEM SET geqo_seed = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_seed;  -- fail, autovacuum_admin has insufficient privileges
+SET geqo_selection_bias = 2;  -- ok
+RESET geqo_selection_bias;  -- ok
+ALTER SYSTEM SET geqo_selection_bias = 2;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_selection_bias;  -- fail, autovacuum_admin has insufficient privileges
+SET geqo_threshold = 1073741824;  -- ok
+RESET geqo_threshold;  -- ok
+ALTER SYSTEM SET geqo_threshold = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET geqo_threshold;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_METHOD
+SET enable_async_append = OFF;  -- ok
+RESET enable_async_append;  -- ok
+ALTER SYSTEM SET enable_async_append = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_async_append;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_bitmapscan = OFF;  -- ok
+RESET enable_bitmapscan;  -- ok
+ALTER SYSTEM SET enable_bitmapscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_bitmapscan;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_gathermerge = OFF;  -- ok
+RESET enable_gathermerge;  -- ok
+ALTER SYSTEM SET enable_gathermerge = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_gathermerge;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_hashagg = OFF;  -- ok
+RESET enable_hashagg;  -- ok
+ALTER SYSTEM SET enable_hashagg = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_hashagg;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_hashjoin = OFF;  -- ok
+RESET enable_hashjoin;  -- ok
+ALTER SYSTEM SET enable_hashjoin = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_hashjoin;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_incremental_sort = OFF;  -- ok
+RESET enable_incremental_sort;  -- ok
+ALTER SYSTEM SET enable_incremental_sort = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_incremental_sort;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_indexonlyscan = OFF;  -- ok
+RESET enable_indexonlyscan;  -- ok
+ALTER SYSTEM SET enable_indexonlyscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_indexonlyscan;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_indexscan = OFF;  -- ok
+RESET enable_indexscan;  -- ok
+ALTER SYSTEM SET enable_indexscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_indexscan;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_material = OFF;  -- ok
+RESET enable_material;  -- ok
+ALTER SYSTEM SET enable_material = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_material;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_memoize = OFF;  -- ok
+RESET enable_memoize;  -- ok
+ALTER SYSTEM SET enable_memoize = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_memoize;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_mergejoin = OFF;  -- ok
+RESET enable_mergejoin;  -- ok
+ALTER SYSTEM SET enable_mergejoin = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_mergejoin;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_nestloop = OFF;  -- ok
+RESET enable_nestloop;  -- ok
+ALTER SYSTEM SET enable_nestloop = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_nestloop;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_parallel_append = OFF;  -- ok
+RESET enable_parallel_append;  -- ok
+ALTER SYSTEM SET enable_parallel_append = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_parallel_append;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_parallel_hash = OFF;  -- ok
+RESET enable_parallel_hash;  -- ok
+ALTER SYSTEM SET enable_parallel_hash = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_parallel_hash;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_partition_pruning = OFF;  -- ok
+RESET enable_partition_pruning;  -- ok
+ALTER SYSTEM SET enable_partition_pruning = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_partition_pruning;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_partitionwise_aggregate = OFF;  -- ok
+RESET enable_partitionwise_aggregate;  -- ok
+ALTER SYSTEM SET enable_partitionwise_aggregate = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_partitionwise_aggregate;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_partitionwise_join = OFF;  -- ok
+RESET enable_partitionwise_join;  -- ok
+ALTER SYSTEM SET enable_partitionwise_join = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_partitionwise_join;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_seqscan = OFF;  -- ok
+RESET enable_seqscan;  -- ok
+ALTER SYSTEM SET enable_seqscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_seqscan;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_sort = OFF;  -- ok
+RESET enable_sort;  -- ok
+ALTER SYSTEM SET enable_sort = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_sort;  -- fail, autovacuum_admin has insufficient privileges
+SET enable_tidscan = OFF;  -- ok
+RESET enable_tidscan;  -- ok
+ALTER SYSTEM SET enable_tidscan = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET enable_tidscan;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / QUERY_TUNING_OTHER
+SET constraint_exclusion = 'partition';  -- ok
+RESET constraint_exclusion;  -- ok
+ALTER SYSTEM SET constraint_exclusion = 'partition';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET constraint_exclusion;  -- fail, autovacuum_admin has insufficient privileges
+SET cursor_tuple_fraction = 0;  -- ok
+RESET cursor_tuple_fraction;  -- ok
+ALTER SYSTEM SET cursor_tuple_fraction = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET cursor_tuple_fraction;  -- fail, autovacuum_admin has insufficient privileges
+SET default_statistics_target = 5000;  -- ok
+RESET default_statistics_target;  -- ok
+ALTER SYSTEM SET default_statistics_target = 5000;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET default_statistics_target;  -- fail, autovacuum_admin has insufficient privileges
+SET from_collapse_limit = 1073741824;  -- ok
+RESET from_collapse_limit;  -- ok
+ALTER SYSTEM SET from_collapse_limit = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET from_collapse_limit;  -- fail, autovacuum_admin has insufficient privileges
+SET jit = OFF;  -- ok
+RESET jit;  -- ok
+ALTER SYSTEM SET jit = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET jit;  -- fail, autovacuum_admin has insufficient privileges
+SET join_collapse_limit = 1073741824;  -- ok
+RESET join_collapse_limit;  -- ok
+ALTER SYSTEM SET join_collapse_limit = 1073741824;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET join_collapse_limit;  -- fail, autovacuum_admin has insufficient privileges
+SET plan_cache_mode = 'force_generic_plan';  -- ok
+RESET plan_cache_mode;  -- ok
+ALTER SYSTEM SET plan_cache_mode = 'force_generic_plan';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET plan_cache_mode;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / REPLICATION_SENDING
+SET wal_sender_timeout = 50;  -- ok
+RESET wal_sender_timeout;  -- ok
+ALTER SYSTEM SET wal_sender_timeout = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_sender_timeout;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / RESOURCES_ASYNCHRONOUS
+SET backend_flush_after = 128;  -- ok
+RESET backend_flush_after;  -- ok
+ALTER SYSTEM SET backend_flush_after = 128;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET backend_flush_after;  -- fail, autovacuum_admin has insufficient privileges
+SET effective_io_concurrency = 0;  -- ok
+RESET effective_io_concurrency;  -- ok
+ALTER SYSTEM SET effective_io_concurrency = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET effective_io_concurrency;  -- fail, autovacuum_admin has insufficient privileges
+SET maintenance_io_concurrency = 0;  -- ok
+RESET maintenance_io_concurrency;  -- ok
+ALTER SYSTEM SET maintenance_io_concurrency = 0;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET maintenance_io_concurrency;  -- fail, autovacuum_admin has insufficient privileges
+SET max_parallel_maintenance_workers = 50;  -- ok
+RESET max_parallel_maintenance_workers;  -- ok
+ALTER SYSTEM SET max_parallel_maintenance_workers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_parallel_maintenance_workers;  -- fail, autovacuum_admin has insufficient privileges
+SET max_parallel_workers = 50;  -- ok
+RESET max_parallel_workers;  -- ok
+ALTER SYSTEM SET max_parallel_workers = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_parallel_workers;  -- fail, autovacuum_admin has insufficient privileges
+SET max_parallel_workers_per_gather = 50;  -- ok
+RESET max_parallel_workers_per_gather;  -- ok
+ALTER SYSTEM SET max_parallel_workers_per_gather = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET max_parallel_workers_per_gather;  -- fail, autovacuum_admin has insufficient privileges
+SET parallel_leader_participation = OFF;  -- ok
+RESET parallel_leader_participation;  -- ok
+ALTER SYSTEM SET parallel_leader_participation = OFF;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET parallel_leader_participation;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / RESOURCES_MEM
+SET hash_mem_multiplier = 500;  -- ok
+RESET hash_mem_multiplier;  -- ok
+ALTER SYSTEM SET hash_mem_multiplier = 500;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET hash_mem_multiplier;  -- fail, autovacuum_admin has insufficient privileges
+SET logical_decoding_work_mem = 1073741855;  -- ok
+RESET logical_decoding_work_mem;  -- ok
+ALTER SYSTEM SET logical_decoding_work_mem = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET logical_decoding_work_mem;  -- fail, autovacuum_admin has insufficient privileges
+SET maintenance_work_mem = 1073742335;  -- ok
+RESET maintenance_work_mem;  -- ok
+ALTER SYSTEM SET maintenance_work_mem = 1073742335;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET maintenance_work_mem;  -- fail, autovacuum_admin has insufficient privileges
+SET temp_buffers = 536870961;  -- ok
+RESET temp_buffers;  -- ok
+ALTER SYSTEM SET temp_buffers = 536870961;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET temp_buffers;  -- fail, autovacuum_admin has insufficient privileges
+SET work_mem = 1073741855;  -- ok
+RESET work_mem;  -- ok
+ALTER SYSTEM SET work_mem = 1073741855;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET work_mem;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / RESOURCES_VACUUM_DELAY
+SET vacuum_cost_delay = 50;  -- ok
+RESET vacuum_cost_delay;  -- ok
+ALTER SYSTEM SET vacuum_cost_delay = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_delay;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_cost_limit = 5000;  -- ok
+RESET vacuum_cost_limit;  -- ok
+ALTER SYSTEM SET vacuum_cost_limit = 5000;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_limit;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_cost_page_dirty = 50;  -- ok
+RESET vacuum_cost_page_dirty;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_dirty = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_page_dirty;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_cost_page_hit = 50;  -- ok
+RESET vacuum_cost_page_hit;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_hit = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_page_hit;  -- fail, autovacuum_admin has insufficient privileges
+SET vacuum_cost_page_miss = 50;  -- ok
+RESET vacuum_cost_page_miss;  -- ok
+ALTER SYSTEM SET vacuum_cost_page_miss = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET vacuum_cost_page_miss;  -- fail, autovacuum_admin has insufficient privileges
+-- PGC_USERSET / UNGROUPED
+SET seed = 0;  -- ok
+RESET seed;  -- ok
+ALTER SYSTEM SET seed = 0;  -- fail, cannot be changed
+ALTER SYSTEM RESET seed;  -- fail, cannot be changed
+-- PGC_USERSET / WAL_SETTINGS
+SET commit_siblings = 50;  -- ok
+RESET commit_siblings;  -- ok
+ALTER SYSTEM SET commit_siblings = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET commit_siblings;  -- fail, autovacuum_admin has insufficient privileges
+SET synchronous_commit = 'remote_write';  -- ok
+RESET synchronous_commit;  -- ok
+ALTER SYSTEM SET synchronous_commit = 'remote_write';  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET synchronous_commit;  -- fail, autovacuum_admin has insufficient privileges
+SET wal_skip_threshold = 50;  -- ok
+RESET wal_skip_threshold;  -- ok
+ALTER SYSTEM SET wal_skip_threshold = 50;  -- fail, autovacuum_admin has insufficient privileges
+ALTER SYSTEM RESET wal_skip_threshold;  -- fail, autovacuum_admin has insufficient privileges
+RESET statement_timeout;
+RESET SESSION AUTHORIZATION;
+DROP ROLE autovacuum_admin;
-- 
2.21.1 (Apple Git-122.3)

